# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/exchange/v1beta1/query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from injective.exchange.v1beta1 import exchange_pb2 as injective_dot_exchange_dot_v1beta1_dot_exchange__pb2
from injective.exchange.v1beta1 import genesis_pb2 as injective_dot_exchange_dot_v1beta1_dot_genesis__pb2
from injective.oracle.v1beta1 import oracle_pb2 as injective_dot_oracle_dot_v1beta1_dot_oracle__pb2
from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='injective/exchange/v1beta1/query.proto',
  package='injective.exchange.v1beta1',
  syntax='proto3',
  serialized_options=b'ZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&injective/exchange/v1beta1/query.proto\x12\x1ainjective.exchange.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a)injective/exchange/v1beta1/exchange.proto\x1a(injective/exchange/v1beta1/genesis.proto\x1a%injective/oracle/v1beta1/oracle.proto\x1a\x14gogoproto/gogo.proto\"6\n\nSubaccount\x12\x0e\n\x06trader\x18\x01 \x01(\t\x12\x18\n\x10subaccount_nonce\x18\x02 \x01(\r\"H\n\x1cQuerySubaccountOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xaa\x01\n\x1dQuerySubaccountOrdersResponse\x12\x43\n\nbuy_orders\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\x12\x44\n\x0bsell_orders\x18\x02 \x03(\x0b\x32/.injective.exchange.v1beta1.SubaccountOrderData\"\x94\x01\n%SubaccountOrderbookMetadataWithMarket\x12I\n\x08metadata\x18\x01 \x01(\x0b\x32\x37.injective.exchange.v1beta1.SubaccountOrderbookMetadata\x12\x11\n\tmarket_id\x18\x02 \x01(\t\x12\r\n\x05isBuy\x18\x03 \x01(\x08\"\x1c\n\x1aQueryExchangeParamsRequest\"W\n\x1bQueryExchangeParamsResponse\x12\x38\n\x06params\x18\x01 \x01(\x0b\x32\".injective.exchange.v1beta1.ParamsB\x04\xc8\xde\x1f\x00\"y\n\x1eQuerySubaccountDepositsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12@\n\nsubaccount\x18\x02 \x01(\x0b\x32&.injective.exchange.v1beta1.SubaccountB\x04\xc8\xde\x1f\x01\"\xd4\x01\n\x1fQuerySubaccountDepositsResponse\x12[\n\x08\x64\x65posits\x18\x01 \x03(\x0b\x32I.injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry\x1aT\n\rDepositsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit:\x02\x38\x01\"\x1e\n\x1cQueryExchangeBalancesRequest\"\\\n\x1dQueryExchangeBalancesResponse\x12;\n\x08\x62\x61lances\x18\x01 \x03(\x0b\x32#.injective.exchange.v1beta1.BalanceB\x04\xc8\xde\x1f\x00\"E\n\x1dQuerySubaccountDepositRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\"W\n\x1eQuerySubaccountDepositResponse\x12\x35\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.injective.exchange.v1beta1.Deposit\")\n\x17QuerySpotMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"S\n\x18QuerySpotMarketsResponse\x12\x37\n\x07markets\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"+\n\x16QuerySpotMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"Q\n\x17QuerySpotMarketResponse\x12\x36\n\x06market\x18\x01 \x01(\x0b\x32&.injective.exchange.v1beta1.SpotMarket\"=\n\x19QuerySpotOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xa1\x01\n\x1aQuerySpotOrderbookResponse\x12@\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.PriceLevel\x12\x41\n\x11sells_price_level\x18\x02 \x03(\x0b\x32&.injective.exchange.v1beta1.PriceLevel\"`\n\x1eQuerySpotOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"d\n\x1fQuerySpotOrdersByHashesResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"H\n\x1cQueryTraderSpotOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"\xfd\x01\n\x15TrimmedSpotLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\r\n\x05isBuy\x18\x04 \x01(\x08\x12\x12\n\norder_hash\x18\x05 \x01(\t\"b\n\x1dQueryTraderSpotOrdersResponse\x12\x41\n\x06orders\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.TrimmedSpotLimitOrder\"3\n\x1eQuerySpotMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xf5\x01\n\x1fQuerySpotMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"9\n$QueryDerivativeMidPriceAndTOBRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"\xfb\x01\n%QueryDerivativeMidPriceAndTOBResponse\x12\x41\n\tmid_price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12\x46\n\x0e\x62\x65st_buy_price\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\x12G\n\x0f\x62\x65st_sell_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"C\n\x1fQueryDerivativeOrderbookRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\r\n\x05limit\x18\x02 \x01(\x04\"\xa7\x01\n QueryDerivativeOrderbookResponse\x12@\n\x10\x62uys_price_level\x18\x01 \x03(\x0b\x32&.injective.exchange.v1beta1.PriceLevel\x12\x41\n\x11sells_price_level\x18\x02 \x03(\x0b\x32&.injective.exchange.v1beta1.PriceLevel\"\xf2\x02\n.QueryTraderSpotOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x43\n\x0b\x62\x61se_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0cquote_amount\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\x08strategy\x18\x05 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"\xb3\x02\n4QueryTraderDerivativeOrdersToCancelUpToAmountRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x44\n\x0cquote_amount\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\x08strategy\x18\x04 \x01(\x0e\x32\x30.injective.exchange.v1beta1.CancellationStrategy\x12G\n\x0freference_price\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x01\"N\n\"QueryTraderDerivativeOrdersRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"\xce\x02\n\x1bTrimmedDerivativeLimitOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08\x66illable\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x12\n\norder_hash\x18\x06 \x01(\t\"n\n#QueryTraderDerivativeOrdersResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"f\n$QueryDerivativeOrdersByHashesRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\x12\x14\n\x0corder_hashes\x18\x03 \x03(\t\"p\n%QueryDerivativeOrdersByHashesResponse\x12G\n\x06orders\x18\x01 \x03(\x0b\x32\x37.injective.exchange.v1beta1.TrimmedDerivativeLimitOrder\"/\n\x1dQueryDerivativeMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"\x8d\x01\n\nPriceLevel\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"\xa6\x01\n\x14PerpetualMarketState\x12\x44\n\x0bmarket_info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfo\x12H\n\x0c\x66unding_info\x18\x02 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFunding\"\xb9\x02\n\x14\x46ullDerivativeMarket\x12<\n\x06market\x18\x01 \x01(\x0b\x32,.injective.exchange.v1beta1.DerivativeMarket\x12J\n\x0eperpetual_info\x18\x02 \x01(\x0b\x32\x30.injective.exchange.v1beta1.PerpetualMarketStateH\x00\x12K\n\x0c\x66utures_info\x18\x03 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoH\x00\x12\x42\n\nmark_price\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x42\x06\n\x04info\"c\n\x1eQueryDerivativeMarketsResponse\x12\x41\n\x07markets\x18\x01 \x03(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"1\n\x1cQueryDerivativeMarketRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"a\n\x1dQueryDerivativeMarketResponse\x12@\n\x06market\x18\x01 \x01(\x0b\x32\x30.injective.exchange.v1beta1.FullDerivativeMarket\"8\n#QueryDerivativeMarketAddressRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"N\n$QueryDerivativeMarketAddressResponse\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x15\n\rsubaccount_id\x18\x02 \x01(\t\"9\n QuerySubaccountTradeNonceRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"8\n\x1fQuerySubaccountPositionsRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"R\n&QuerySubaccountPositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"[\n/QuerySubaccountEffectivePositionInMarketRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"<\n#QuerySubaccountOrderMetadataRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\"g\n QuerySubaccountPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"d\n\'QuerySubaccountPositionInMarketResponse\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32$.injective.exchange.v1beta1.PositionB\x04\xc8\xde\x1f\x01\"\xf5\x01\n\x11\x45\x66\x66\x65\x63tivePosition\x12\x0f\n\x07is_long\x18\x01 \x01(\x08\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x43\n\x0b\x65ntry_price\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12H\n\x10\x65\x66\x66\x65\x63tive_margin\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"v\n0QuerySubaccountEffectivePositionInMarketResponse\x12\x42\n\x05state\x18\x01 \x01(\x0b\x32-.injective.exchange.v1beta1.EffectivePositionB\x04\xc8\xde\x1f\x01\"4\n\x1fQueryPerpetualMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"g\n QueryPerpetualMarketInfoResponse\x12\x43\n\x04info\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.PerpetualMarketInfoB\x04\xc8\xde\x1f\x00\"8\n#QueryExpiryFuturesMarketInfoRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"o\n$QueryExpiryFuturesMarketInfoResponse\x12G\n\x04info\x18\x01 \x01(\x0b\x32\x33.injective.exchange.v1beta1.ExpiryFuturesMarketInfoB\x04\xc8\xde\x1f\x00\"7\n\"QueryPerpetualMarketFundingRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"n\n#QueryPerpetualMarketFundingResponse\x12G\n\x05state\x18\x01 \x01(\x0b\x32\x32.injective.exchange.v1beta1.PerpetualMarketFundingB\x04\xc8\xde\x1f\x00\"\x81\x01\n$QuerySubaccountOrderMetadataResponse\x12Y\n\x08metadata\x18\x01 \x03(\x0b\x32\x41.injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarketB\x04\xc8\xde\x1f\x00\"2\n!QuerySubaccountTradeNonceResponse\x12\r\n\x05nonce\x18\x01 \x01(\r\"\x19\n\x17QueryModuleStateRequest\"S\n\x18QueryModuleStateResponse\x12\x37\n\x05state\x18\x01 \x01(\x0b\x32(.injective.exchange.v1beta1.GenesisState\"\x17\n\x15QueryPositionsRequest\"]\n\x16QueryPositionsResponse\x12\x43\n\x05state\x18\x01 \x03(\x0b\x32..injective.exchange.v1beta1.DerivativePositionB\x04\xc8\xde\x1f\x00\"Q\n\x1dQueryTradeRewardPointsRequest\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\x12\x1e\n\x16pending_pool_timestamp\x18\x02 \x01(\x03\"u\n\x1eQueryTradeRewardPointsResponse\x12S\n\x1b\x61\x63\x63ount_trade_reward_points\x18\x01 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"!\n\x1fQueryTradeRewardCampaignRequest\"\xf3\x03\n QueryTradeRewardCampaignResponse\x12[\n\x1ctrading_reward_campaign_info\x18\x01 \x01(\x0b\x32\x35.injective.exchange.v1beta1.TradingRewardCampaignInfo\x12]\n%trading_reward_pool_campaign_schedule\x18\x02 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Q\n\x19total_trade_reward_points\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x65\n-pending_trading_reward_pool_campaign_schedule\x18\x04 \x03(\x0b\x32..injective.exchange.v1beta1.CampaignRewardPool\x12Y\n!pending_total_trade_reward_points\x18\x05 \x03(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"2\n\x1fQueryIsOptedOutOfRewardsRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"8\n QueryIsOptedOutOfRewardsResponse\x12\x14\n\x0cis_opted_out\x18\x01 \x01(\x08\"\'\n%QueryOptedOutOfRewardsAccountsRequest\":\n&QueryOptedOutOfRewardsAccountsResponse\x12\x10\n\x08\x61\x63\x63ounts\x18\x01 \x03(\t\"5\n\"QueryFeeDiscountAccountInfoRequest\x12\x0f\n\x07\x61\x63\x63ount\x18\x01 \x01(\t\"\xc5\x01\n#QueryFeeDiscountAccountInfoResponse\x12\x12\n\ntier_level\x18\x01 \x01(\x04\x12\x45\n\x0c\x61\x63\x63ount_info\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountTierInfo\x12\x43\n\x0b\x61\x63\x63ount_ttl\x18\x03 \x01(\x0b\x32..injective.exchange.v1beta1.FeeDiscountTierTTL\"!\n\x1fQueryFeeDiscountScheduleRequest\"r\n QueryFeeDiscountScheduleResponse\x12N\n\x15\x66\x65\x65_discount_schedule\x18\x01 \x01(\x0b\x32/.injective.exchange.v1beta1.FeeDiscountSchedule\"4\n\x1dQueryBalanceMismatchesRequest\x12\x13\n\x0b\x64ust_factor\x18\x01 \x01(\x03\"\x8a\x03\n\x0f\x42\x61lanceMismatch\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05total\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x46\n\x0e\x65xpected_total\x18\x06 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x42\n\ndifference\x18\x07 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"i\n\x1eQueryBalanceMismatchesResponse\x12G\n\x12\x62\x61lance_mismatches\x18\x01 \x03(\x0b\x32+.injective.exchange.v1beta1.BalanceMismatch\"%\n#QueryBalanceWithBalanceHoldsRequest\"\x84\x02\n\x15\x42\x61lanceWithMarginHold\x12\x14\n\x0csubaccountId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65nom\x18\x02 \x01(\t\x12\x41\n\tavailable\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12=\n\x05total\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0c\x62\x61lance_hold\x18\x05 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\"}\n$QueryBalanceWithBalanceHoldsResponse\x12U\n\x1a\x62\x61lance_with_balance_holds\x18\x01 \x03(\x0b\x32\x31.injective.exchange.v1beta1.BalanceWithMarginHold\"\'\n%QueryFeeDiscountTierStatisticsRequest\",\n\rTierStatistic\x12\x0c\n\x04tier\x18\x01 \x01(\x04\x12\r\n\x05\x63ount\x18\x02 \x01(\x04\"g\n&QueryFeeDiscountTierStatisticsResponse\x12=\n\nstatistics\x18\x01 \x03(\x0b\x32).injective.exchange.v1beta1.TierStatistic\"\x18\n\x16NinjaVaultInfosRequest\"\x81\x01\n\x17NinjaVaultInfosResponse\x12\x18\n\x10master_addresses\x18\x01 \x03(\t\x12\x1c\n\x14\x64\x65rivative_addresses\x18\x02 \x03(\t\x12\x16\n\x0espot_addresses\x18\x03 \x03(\t\x12\x16\n\x0e\x63w20_addresses\x18\x04 \x03(\t\"<\n\x1dQueryMarketIDFromVaultRequest\x12\x1b\n\x13vault_subaccount_id\x18\x01 \x01(\t\"3\n\x1eQueryMarketIDFromVaultResponse\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"7\n\"QueryHistoricalTradeRecordsRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\"f\n#QueryHistoricalTradeRecordsResponse\x12?\n\rtrade_records\x18\x01 \x03(\x0b\x32(.injective.exchange.v1beta1.TradeRecords\"y\n\x13TradeHistoryOptions\x12\x1a\n\x12trade_grouping_sec\x18\x01 \x01(\x04\x12\x0f\n\x07max_age\x18\x02 \x01(\x04\x12\x1b\n\x13include_raw_history\x18\x04 \x01(\x08\x12\x18\n\x10include_metadata\x18\x05 \x01(\x08\"\x81\x01\n\x1cQueryMarketVolatilityRequest\x12\x11\n\tmarket_id\x18\x01 \x01(\t\x12N\n\x15trade_history_options\x18\x02 \x01(\x0b\x32/.injective.exchange.v1beta1.TradeHistoryOptions\"\xe5\x01\n\x1dQueryMarketVolatilityResponse\x12>\n\nvolatility\x18\x01 \x01(\tB*\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\x12\x46\n\x10history_metadata\x18\x02 \x01(\x0b\x32,.injective.oracle.v1beta1.MetadataStatistics\x12<\n\x0braw_history\x18\x03 \x03(\x0b\x32\'.injective.exchange.v1beta1.TradeRecord\"+\n\x19QueryBinaryMarketsRequest\x12\x0e\n\x06status\x18\x01 \x01(\t\"^\n\x1aQueryBinaryMarketsResponse\x12@\n\x07markets\x18\x01 \x03(\x0b\x32/.injective.exchange.v1beta1.BinaryOptionsMarket\"Y\n-QueryTraderDerivativeConditionalOrdersRequest\x12\x15\n\rsubaccount_id\x18\x01 \x01(\t\x12\x11\n\tmarket_id\x18\x02 \x01(\t\"\xf6\x02\n!TrimmedDerivativeConditionalOrder\x12=\n\x05price\x18\x01 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12@\n\x08quantity\x18\x02 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12>\n\x06margin\x18\x03 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x44\n\x0ctriggerPrice\x18\x04 \x01(\tB.\xda\xde\x1f&github.com/cosmos/cosmos-sdk/types.Dec\xc8\xde\x1f\x00\x12\x18\n\x05isBuy\x18\x05 \x01(\x08\x42\t\xea\xde\x1f\x05isBuy\x12\x1c\n\x07isLimit\x18\x06 \x01(\x08\x42\x0b\xea\xde\x1f\x07isLimit\x12\x12\n\norder_hash\x18\x07 \x01(\t\"\x7f\n.QueryTraderDerivativeConditionalOrdersResponse\x12M\n\x06orders\x18\x01 \x03(\x0b\x32=.injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder*V\n\x14\x43\x61ncellationStrategy\x12\x14\n\x10UnspecifiedOrder\x10\x00\x12\x13\n\x0f\x46romWorstToBest\x10\x01\x12\x13\n\x0f\x46romBestToWorst\x10\x02\x32\xe6M\n\x05Query\x12\xba\x01\n\x13QueryExchangeParams\x12\x36.injective.exchange.v1beta1.QueryExchangeParamsRequest\x1a\x37.injective.exchange.v1beta1.QueryExchangeParamsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/exchange/v1beta1/exchangeParams\x12\xce\x01\n\x12SubaccountDeposits\x12:.injective.exchange.v1beta1.QuerySubaccountDepositsRequest\x1a;.injective.exchange.v1beta1.QuerySubaccountDepositsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/exchange/subaccountDeposits\x12\xca\x01\n\x11SubaccountDeposit\x12\x39.injective.exchange.v1beta1.QuerySubaccountDepositRequest\x1a:.injective.exchange.v1beta1.QuerySubaccountDepositResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/exchange/subaccountDeposit\x12\xc6\x01\n\x10\x45xchangeBalances\x12\x38.injective.exchange.v1beta1.QueryExchangeBalancesRequest\x1a\x39.injective.exchange.v1beta1.QueryExchangeBalancesResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/exchange/exchangeBalances\x12\xaa\x01\n\x0bSpotMarkets\x12\x33.injective.exchange.v1beta1.QuerySpotMarketsRequest\x1a\x34.injective.exchange.v1beta1.QuerySpotMarketsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/spot/markets\x12\xb3\x01\n\nSpotMarket\x12\x32.injective.exchange.v1beta1.QuerySpotMarketRequest\x1a\x33.injective.exchange.v1beta1.QuerySpotMarketResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/spot/markets/{market_id}\x12\xbe\x01\n\rSpotOrderbook\x12\x35.injective.exchange.v1beta1.QuerySpotOrderbookRequest\x1a\x36.injective.exchange.v1beta1.QuerySpotOrderbookResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/injective/exchange/v1beta1/spot/orderbook/{market_id}\x12\xd4\x01\n\x10TraderSpotOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}\x12\xe4\x01\n\x12SpotOrdersByHashes\x12:.injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest\x1a;.injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}\x12\xc3\x01\n\x10SubaccountOrders\x12\x38.injective.exchange.v1beta1.QuerySubaccountOrdersRequest\x1a\x39.injective.exchange.v1beta1.QuerySubaccountOrdersResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/orders/{subaccount_id}\x12\xe7\x01\n\x19TraderSpotTransientOrders\x12\x38.injective.exchange.v1beta1.QueryTraderSpotOrdersRequest\x1a\x39.injective.exchange.v1beta1.QueryTraderSpotOrdersResponse\"U\x82\xd3\xe4\x93\x02O\x12M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}\x12\xd5\x01\n\x12SpotMidPriceAndTOB\x12:.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest\x1a;.injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse\"F\x82\xd3\xe4\x93\x02@\x12>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}\x12\xed\x01\n\x18\x44\x65rivativeMidPriceAndTOB\x12@.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}\x12\xd6\x01\n\x13\x44\x65rivativeOrderbook\x12;.injective.exchange.v1beta1.QueryDerivativeOrderbookRequest\x1a<.injective.exchange.v1beta1.QueryDerivativeOrderbookResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/derivative/orderbook/{market_id}\x12\xec\x01\n\x16TraderDerivativeOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"Q\x82\xd3\xe4\x93\x02K\x12I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}\x12\xfc\x01\n\x18\x44\x65rivativeOrdersByHashes\x12@.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest\x1a\x41.injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}\x12\xff\x01\n\x1fTraderDerivativeTransientOrders\x12>.injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest\x1a?.injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse\"[\x82\xd3\xe4\x93\x02U\x12S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}\x12\xc2\x01\n\x11\x44\x65rivativeMarkets\x12\x39.injective.exchange.v1beta1.QueryDerivativeMarketsRequest\x1a:.injective.exchange.v1beta1.QueryDerivativeMarketsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./injective/exchange/v1beta1/derivative/markets\x12\xcb\x01\n\x10\x44\x65rivativeMarket\x12\x38.injective.exchange.v1beta1.QueryDerivativeMarketRequest\x1a\x39.injective.exchange.v1beta1.QueryDerivativeMarketResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/derivative/markets/{market_id}\x12\xe7\x01\n\x17\x44\x65rivativeMarketAddress\x12?.injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest\x1a@.injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/derivative/market_address/{market_id}\x12\xd1\x01\n\x14SubaccountTradeNonce\x12<.injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest\x1a=.injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/exchange/{subaccount_id}\x12\xb2\x01\n\x13\x45xchangeModuleState\x12\x33.injective.exchange.v1beta1.QueryModuleStateRequest\x1a\x34.injective.exchange.v1beta1.QueryModuleStateResponse\"0\x82\xd3\xe4\x93\x02*\x12(/injective/exchange/v1beta1/module_state\x12\xa1\x01\n\tPositions\x12\x31.injective.exchange.v1beta1.QueryPositionsRequest\x1a\x32.injective.exchange.v1beta1.QueryPositionsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/injective/exchange/v1beta1/positions\x12\xcf\x01\n\x13SubaccountPositions\x12;.injective.exchange.v1beta1.QuerySubaccountPositionsRequest\x1a<.injective.exchange.v1beta1.QuerySubaccountPositionsResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/injective/exchange/v1beta1/positions/{subaccount_id}\x12\xf0\x01\n\x1aSubaccountPositionInMarket\x12\x42.injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest\x1a\x43.injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}\x12\x95\x02\n#SubaccountEffectivePositionInMarket\x12K.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest\x1aL.injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse\"S\x82\xd3\xe4\x93\x02M\x12K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}\x12\xd7\x01\n\x13PerpetualMarketInfo\x12;.injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest\x1a<.injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/perpetual_market_info/{market_id}\x12\xe0\x01\n\x17\x45xpiryFuturesMarketInfo\x12?.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest\x1a@.injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/expiry_market_info/{market_id}\x12\xe3\x01\n\x16PerpetualMarketFunding\x12>.injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest\x1a?.injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse\"H\x82\xd3\xe4\x93\x02\x42\x12@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}\x12\xe0\x01\n\x17SubaccountOrderMetadata\x12?.injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest\x1a@.injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse\"B\x82\xd3\xe4\x93\x02<\x12:/injective/exchange/v1beta1/order_metadata/{subaccount_id}\x12\xc3\x01\n\x11TradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//injective/exchange/v1beta1/trade_reward_points\x12\xd2\x01\n\x18PendingTradeRewardPoints\x12\x39.injective.exchange.v1beta1.QueryTradeRewardPointsRequest\x1a:.injective.exchange.v1beta1.QueryTradeRewardPointsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/pending_trade_reward_points\x12\xcb\x01\n\x13TradeRewardCampaign\x12;.injective.exchange.v1beta1.QueryTradeRewardCampaignRequest\x1a<.injective.exchange.v1beta1.QueryTradeRewardCampaignResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/trade_reward_campaign\x12\xe2\x01\n\x16\x46\x65\x65\x44iscountAccountInfo\x12>.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest\x1a?.injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/injective/exchange/v1beta1/fee_discount_account_info/{account}\x12\xcb\x01\n\x13\x46\x65\x65\x44iscountSchedule\x12;.injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest\x1a<.injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/injective/exchange/v1beta1/fee_discount_schedule\x12\xd0\x01\n\x11\x42\x61lanceMismatches\x12\x39.injective.exchange.v1beta1.QueryBalanceMismatchesRequest\x1a:.injective.exchange.v1beta1.QueryBalanceMismatchesResponse\"D\x82\xd3\xe4\x93\x02>\x12</injective/exchange/v1beta1/balance_mismatches/{dust_factor}\x12\xdd\x01\n\x17\x42\x61lanceWithBalanceHolds\x12?.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest\x1a@.injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/injective/exchange/v1beta1/balances_with_balance_holds\x12\xdf\x01\n\x19\x46\x65\x65\x44iscountTierStatistics\x12\x41.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest\x1a\x42.injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/injective/exchange/v1beta1/fee_discount_tier_stats\x12\xb1\x01\n\x0fNinjaVaultInfos\x12\x32.injective.exchange.v1beta1.NinjaVaultInfosRequest\x1a\x33.injective.exchange.v1beta1.NinjaVaultInfosResponse\"5\x82\xd3\xe4\x93\x02/\x12-/injective/exchange/v1beta1/ninja_vault_infos\x12\xda\x01\n\x16QueryMarketIDFromVault\x12\x39.injective.exchange.v1beta1.QueryMarketIDFromVaultRequest\x1a:.injective.exchange.v1beta1.QueryMarketIDFromVaultResponse\"I\x82\xd3\xe4\x93\x02\x43\x12\x41/injective/exchange/v1beta1/vault_market_id/{vault_subaccount_id}\x12\xd7\x01\n\x16HistoricalTradeRecords\x12>.injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest\x1a?.injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/injective/exchange/v1beta1/historical_trade_records\x12\xd7\x01\n\x13IsOptedOutOfRewards\x12;.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest\x1a<.injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse\"E\x82\xd3\xe4\x93\x02?\x12=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}\x12\xe5\x01\n\x19OptedOutOfRewardsAccounts\x12\x41.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest\x1a\x42.injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/opted_out_of_rewards_accounts\x12\xca\x01\n\x10MarketVolatility\x12\x38.injective.exchange.v1beta1.QueryMarketVolatilityRequest\x1a\x39.injective.exchange.v1beta1.QueryMarketVolatilityResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/injective/exchange/v1beta1/market_volatility/{market_id}\x12\xc1\x01\n\x14\x42inaryOptionsMarkets\x12\x35.injective.exchange.v1beta1.QueryBinaryMarketsRequest\x1a\x36.injective.exchange.v1beta1.QueryBinaryMarketsResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/exchange/v1beta1/binary_options/markets\x12\x99\x02\n!TraderDerivativeConditionalOrders\x12I.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest\x1aJ.injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse\"]\x82\xd3\xe4\x93\x02W\x12U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}BPZNgithub.com/InjectiveLabs/injective-core/injective-chain/modules/exchange/typesb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_exchange__pb2.DESCRIPTOR,injective_dot_exchange_dot_v1beta1_dot_genesis__pb2.DESCRIPTOR,injective_dot_oracle_dot_v1beta1_dot_oracle__pb2.DESCRIPTOR,gogoproto_dot_gogo__pb2.DESCRIPTOR,])

_CANCELLATIONSTRATEGY = _descriptor.EnumDescriptor(
  name='CancellationStrategy',
  full_name='injective.exchange.v1beta1.CancellationStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UnspecifiedOrder', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FromWorstToBest', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FromBestToWorst', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=11946,
  serialized_end=12032,
)
_sym_db.RegisterEnumDescriptor(_CANCELLATIONSTRATEGY)

CancellationStrategy = enum_type_wrapper.EnumTypeWrapper(_CANCELLATIONSTRATEGY)
UnspecifiedOrder = 0
FromWorstToBest = 1
FromBestToWorst = 2



_SUBACCOUNT = _descriptor.Descriptor(
  name='Subaccount',
  full_name='injective.exchange.v1beta1.Subaccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trader', full_name='injective.exchange.v1beta1.Subaccount.trader', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_nonce', full_name='injective.exchange.v1beta1.Subaccount.subaccount_nonce', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=300,
)


_QUERYSUBACCOUNTORDERSREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountOrdersRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountOrdersRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySubaccountOrdersRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=374,
)


_QUERYSUBACCOUNTORDERSRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountOrdersResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buy_orders', full_name='injective.exchange.v1beta1.QuerySubaccountOrdersResponse.buy_orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sell_orders', full_name='injective.exchange.v1beta1.QuerySubaccountOrdersResponse.sell_orders', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=547,
)


_SUBACCOUNTORDERBOOKMETADATAWITHMARKET = _descriptor.Descriptor(
  name='SubaccountOrderbookMetadataWithMarket',
  full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarket.metadata', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarket.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuy', full_name='injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarket.isBuy', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=550,
  serialized_end=698,
)


_QUERYEXCHANGEPARAMSREQUEST = _descriptor.Descriptor(
  name='QueryExchangeParamsRequest',
  full_name='injective.exchange.v1beta1.QueryExchangeParamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=700,
  serialized_end=728,
)


_QUERYEXCHANGEPARAMSRESPONSE = _descriptor.Descriptor(
  name='QueryExchangeParamsResponse',
  full_name='injective.exchange.v1beta1.QueryExchangeParamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='params', full_name='injective.exchange.v1beta1.QueryExchangeParamsResponse.params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=730,
  serialized_end=817,
)


_QUERYSUBACCOUNTDEPOSITSREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountDepositsRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountDepositsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountDepositsRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount', full_name='injective.exchange.v1beta1.QuerySubaccountDepositsRequest.subaccount', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=819,
  serialized_end=940,
)


_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY = _descriptor.Descriptor(
  name='DepositsEntry',
  full_name='injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1155,
)

_QUERYSUBACCOUNTDEPOSITSRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountDepositsResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountDepositsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposits', full_name='injective.exchange.v1beta1.QuerySubaccountDepositsResponse.deposits', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1155,
)


_QUERYEXCHANGEBALANCESREQUEST = _descriptor.Descriptor(
  name='QueryExchangeBalancesRequest',
  full_name='injective.exchange.v1beta1.QueryExchangeBalancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1157,
  serialized_end=1187,
)


_QUERYEXCHANGEBALANCESRESPONSE = _descriptor.Descriptor(
  name='QueryExchangeBalancesResponse',
  full_name='injective.exchange.v1beta1.QueryExchangeBalancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balances', full_name='injective.exchange.v1beta1.QueryExchangeBalancesResponse.balances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1189,
  serialized_end=1281,
)


_QUERYSUBACCOUNTDEPOSITREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountDepositRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountDepositRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountDepositRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.QuerySubaccountDepositRequest.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1352,
)


_QUERYSUBACCOUNTDEPOSITRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountDepositResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountDepositResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='deposits', full_name='injective.exchange.v1beta1.QuerySubaccountDepositResponse.deposits', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1441,
)


_QUERYSPOTMARKETSREQUEST = _descriptor.Descriptor(
  name='QuerySpotMarketsRequest',
  full_name='injective.exchange.v1beta1.QuerySpotMarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.QuerySpotMarketsRequest.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1484,
)


_QUERYSPOTMARKETSRESPONSE = _descriptor.Descriptor(
  name='QuerySpotMarketsResponse',
  full_name='injective.exchange.v1beta1.QuerySpotMarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective.exchange.v1beta1.QuerySpotMarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1486,
  serialized_end=1569,
)


_QUERYSPOTMARKETREQUEST = _descriptor.Descriptor(
  name='QuerySpotMarketRequest',
  full_name='injective.exchange.v1beta1.QuerySpotMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySpotMarketRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1571,
  serialized_end=1614,
)


_QUERYSPOTMARKETRESPONSE = _descriptor.Descriptor(
  name='QuerySpotMarketResponse',
  full_name='injective.exchange.v1beta1.QuerySpotMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.QuerySpotMarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1616,
  serialized_end=1697,
)


_QUERYSPOTORDERBOOKREQUEST = _descriptor.Descriptor(
  name='QuerySpotOrderbookRequest',
  full_name='injective.exchange.v1beta1.QuerySpotOrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySpotOrderbookRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective.exchange.v1beta1.QuerySpotOrderbookRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1699,
  serialized_end=1760,
)


_QUERYSPOTORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='QuerySpotOrderbookResponse',
  full_name='injective.exchange.v1beta1.QuerySpotOrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buys_price_level', full_name='injective.exchange.v1beta1.QuerySpotOrderbookResponse.buys_price_level', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells_price_level', full_name='injective.exchange.v1beta1.QuerySpotOrderbookResponse.sells_price_level', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1763,
  serialized_end=1924,
)


_QUERYSPOTORDERSBYHASHESREQUEST = _descriptor.Descriptor(
  name='QuerySpotOrdersByHashesRequest',
  full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hashes', full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest.order_hashes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1926,
  serialized_end=2022,
)


_QUERYSPOTORDERSBYHASHESRESPONSE = _descriptor.Descriptor(
  name='QuerySpotOrdersByHashesResponse',
  full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2024,
  serialized_end=2124,
)


_QUERYTRADERSPOTORDERSREQUEST = _descriptor.Descriptor(
  name='QueryTraderSpotOrdersRequest',
  full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2126,
  serialized_end=2198,
)


_TRIMMEDSPOTLIMITORDER = _descriptor.Descriptor(
  name='TrimmedSpotLimitOrder',
  full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fillable', full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder.fillable', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuy', full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder.isBuy', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.TrimmedSpotLimitOrder.order_hash', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2201,
  serialized_end=2454,
)


_QUERYTRADERSPOTORDERSRESPONSE = _descriptor.Descriptor(
  name='QueryTraderSpotOrdersResponse',
  full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2456,
  serialized_end=2554,
)


_QUERYSPOTMIDPRICEANDTOBREQUEST = _descriptor.Descriptor(
  name='QuerySpotMidPriceAndTOBRequest',
  full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2607,
)


_QUERYSPOTMIDPRICEANDTOBRESPONSE = _descriptor.Descriptor(
  name='QuerySpotMidPriceAndTOBResponse',
  full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid_price', full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse.mid_price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='best_buy_price', full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse.best_buy_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='best_sell_price', full_name='injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse.best_sell_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2610,
  serialized_end=2855,
)


_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeMidPriceAndTOBRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2857,
  serialized_end=2914,
)


_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeMidPriceAndTOBResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mid_price', full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse.mid_price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='best_buy_price', full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse.best_buy_price', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='best_sell_price', full_name='injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse.best_sell_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2917,
  serialized_end=3168,
)


_QUERYDERIVATIVEORDERBOOKREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeOrderbookRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limit', full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookRequest.limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3170,
  serialized_end=3237,
)


_QUERYDERIVATIVEORDERBOOKRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeOrderbookResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buys_price_level', full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookResponse.buys_price_level', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells_price_level', full_name='injective.exchange.v1beta1.QueryDerivativeOrderbookResponse.sells_price_level', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3240,
  serialized_end=3407,
)


_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST = _descriptor.Descriptor(
  name='QueryTraderSpotOrdersToCancelUpToAmountRequest',
  full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='base_amount', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.base_amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_amount', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.quote_amount', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.strategy', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_price', full_name='injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest.reference_price', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3410,
  serialized_end=3780,
)


_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST = _descriptor.Descriptor(
  name='QueryTraderDerivativeOrdersToCancelUpToAmountRequest',
  full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quote_amount', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest.quote_amount', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest.strategy', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_price', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest.reference_price', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3783,
  serialized_end=4090,
)


_QUERYTRADERDERIVATIVEORDERSREQUEST = _descriptor.Descriptor(
  name='QueryTraderDerivativeOrdersRequest',
  full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4092,
  serialized_end=4170,
)


_TRIMMEDDERIVATIVELIMITORDER = _descriptor.Descriptor(
  name='TrimmedDerivativeLimitOrder',
  full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.margin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fillable', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.fillable', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuy', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.isBuy', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\005isBuy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.TrimmedDerivativeLimitOrder.order_hash', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4173,
  serialized_end=4507,
)


_QUERYTRADERDERIVATIVEORDERSRESPONSE = _descriptor.Descriptor(
  name='QueryTraderDerivativeOrdersResponse',
  full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4509,
  serialized_end=4619,
)


_QUERYDERIVATIVEORDERSBYHASHESREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeOrdersByHashesRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hashes', full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest.order_hashes', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4621,
  serialized_end=4723,
)


_QUERYDERIVATIVEORDERSBYHASHESRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeOrdersByHashesResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4725,
  serialized_end=4837,
)


_QUERYDERIVATIVEMARKETSREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeMarketsRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.QueryDerivativeMarketsRequest.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4839,
  serialized_end=4886,
)


_PRICELEVEL = _descriptor.Descriptor(
  name='PriceLevel',
  full_name='injective.exchange.v1beta1.PriceLevel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.PriceLevel.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.PriceLevel.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4889,
  serialized_end=5030,
)


_PERPETUALMARKETSTATE = _descriptor.Descriptor(
  name='PerpetualMarketState',
  full_name='injective.exchange.v1beta1.PerpetualMarketState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_info', full_name='injective.exchange.v1beta1.PerpetualMarketState.market_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='funding_info', full_name='injective.exchange.v1beta1.PerpetualMarketState.funding_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5033,
  serialized_end=5199,
)


_FULLDERIVATIVEMARKET = _descriptor.Descriptor(
  name='FullDerivativeMarket',
  full_name='injective.exchange.v1beta1.FullDerivativeMarket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.FullDerivativeMarket.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='perpetual_info', full_name='injective.exchange.v1beta1.FullDerivativeMarket.perpetual_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='futures_info', full_name='injective.exchange.v1beta1.FullDerivativeMarket.futures_info', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mark_price', full_name='injective.exchange.v1beta1.FullDerivativeMarket.mark_price', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='info', full_name='injective.exchange.v1beta1.FullDerivativeMarket.info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=5202,
  serialized_end=5515,
)


_QUERYDERIVATIVEMARKETSRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeMarketsResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective.exchange.v1beta1.QueryDerivativeMarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5517,
  serialized_end=5616,
)


_QUERYDERIVATIVEMARKETREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeMarketRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryDerivativeMarketRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5618,
  serialized_end=5667,
)


_QUERYDERIVATIVEMARKETRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeMarketResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market', full_name='injective.exchange.v1beta1.QueryDerivativeMarketResponse.market', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5669,
  serialized_end=5766,
)


_QUERYDERIVATIVEMARKETADDRESSREQUEST = _descriptor.Descriptor(
  name='QueryDerivativeMarketAddressRequest',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5768,
  serialized_end=5824,
)


_QUERYDERIVATIVEMARKETADDRESSRESPONSE = _descriptor.Descriptor(
  name='QueryDerivativeMarketAddressResponse',
  full_name='injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse.subaccount_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5826,
  serialized_end=5904,
)


_QUERYSUBACCOUNTTRADENONCEREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountTradeNonceRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5906,
  serialized_end=5963,
)


_QUERYSUBACCOUNTPOSITIONSREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountPositionsRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountPositionsRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5965,
  serialized_end=6021,
)


_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountPositionInMarketRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6023,
  serialized_end=6105,
)


_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountEffectivePositionInMarketRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6107,
  serialized_end=6198,
)


_QUERYSUBACCOUNTORDERMETADATAREQUEST = _descriptor.Descriptor(
  name='QuerySubaccountOrderMetadataRequest',
  full_name='injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6200,
  serialized_end=6260,
)


_QUERYSUBACCOUNTPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountPositionsResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QuerySubaccountPositionsResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6262,
  serialized_end=6365,
)


_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountPositionInMarketResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6367,
  serialized_end=6467,
)


_EFFECTIVEPOSITION = _descriptor.Descriptor(
  name='EffectivePosition',
  full_name='injective.exchange.v1beta1.EffectivePosition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_long', full_name='injective.exchange.v1beta1.EffectivePosition.is_long', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.EffectivePosition.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entry_price', full_name='injective.exchange.v1beta1.EffectivePosition.entry_price', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='effective_margin', full_name='injective.exchange.v1beta1.EffectivePosition.effective_margin', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6470,
  serialized_end=6715,
)


_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountEffectivePositionInMarketResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6717,
  serialized_end=6835,
)


_QUERYPERPETUALMARKETINFOREQUEST = _descriptor.Descriptor(
  name='QueryPerpetualMarketInfoRequest',
  full_name='injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6837,
  serialized_end=6889,
)


_QUERYPERPETUALMARKETINFORESPONSE = _descriptor.Descriptor(
  name='QueryPerpetualMarketInfoResponse',
  full_name='injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6891,
  serialized_end=6994,
)


_QUERYEXPIRYFUTURESMARKETINFOREQUEST = _descriptor.Descriptor(
  name='QueryExpiryFuturesMarketInfoRequest',
  full_name='injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6996,
  serialized_end=7052,
)


_QUERYEXPIRYFUTURESMARKETINFORESPONSE = _descriptor.Descriptor(
  name='QueryExpiryFuturesMarketInfoResponse',
  full_name='injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse.info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7054,
  serialized_end=7165,
)


_QUERYPERPETUALMARKETFUNDINGREQUEST = _descriptor.Descriptor(
  name='QueryPerpetualMarketFundingRequest',
  full_name='injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7167,
  serialized_end=7222,
)


_QUERYPERPETUALMARKETFUNDINGRESPONSE = _descriptor.Descriptor(
  name='QueryPerpetualMarketFundingResponse',
  full_name='injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7224,
  serialized_end=7334,
)


_QUERYSUBACCOUNTORDERMETADATARESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountOrderMetadataResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='metadata', full_name='injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse.metadata', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7337,
  serialized_end=7466,
)


_QUERYSUBACCOUNTTRADENONCERESPONSE = _descriptor.Descriptor(
  name='QuerySubaccountTradeNonceResponse',
  full_name='injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='nonce', full_name='injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse.nonce', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7468,
  serialized_end=7518,
)


_QUERYMODULESTATEREQUEST = _descriptor.Descriptor(
  name='QueryModuleStateRequest',
  full_name='injective.exchange.v1beta1.QueryModuleStateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7520,
  serialized_end=7545,
)


_QUERYMODULESTATERESPONSE = _descriptor.Descriptor(
  name='QueryModuleStateResponse',
  full_name='injective.exchange.v1beta1.QueryModuleStateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QueryModuleStateResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7547,
  serialized_end=7630,
)


_QUERYPOSITIONSREQUEST = _descriptor.Descriptor(
  name='QueryPositionsRequest',
  full_name='injective.exchange.v1beta1.QueryPositionsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7632,
  serialized_end=7655,
)


_QUERYPOSITIONSRESPONSE = _descriptor.Descriptor(
  name='QueryPositionsResponse',
  full_name='injective.exchange.v1beta1.QueryPositionsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='injective.exchange.v1beta1.QueryPositionsResponse.state', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7657,
  serialized_end=7750,
)


_QUERYTRADEREWARDPOINTSREQUEST = _descriptor.Descriptor(
  name='QueryTradeRewardPointsRequest',
  full_name='injective.exchange.v1beta1.QueryTradeRewardPointsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='injective.exchange.v1beta1.QueryTradeRewardPointsRequest.accounts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_pool_timestamp', full_name='injective.exchange.v1beta1.QueryTradeRewardPointsRequest.pending_pool_timestamp', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7752,
  serialized_end=7833,
)


_QUERYTRADEREWARDPOINTSRESPONSE = _descriptor.Descriptor(
  name='QueryTradeRewardPointsResponse',
  full_name='injective.exchange.v1beta1.QueryTradeRewardPointsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_trade_reward_points', full_name='injective.exchange.v1beta1.QueryTradeRewardPointsResponse.account_trade_reward_points', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7835,
  serialized_end=7952,
)


_QUERYTRADEREWARDCAMPAIGNREQUEST = _descriptor.Descriptor(
  name='QueryTradeRewardCampaignRequest',
  full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7954,
  serialized_end=7987,
)


_QUERYTRADEREWARDCAMPAIGNRESPONSE = _descriptor.Descriptor(
  name='QueryTradeRewardCampaignResponse',
  full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trading_reward_campaign_info', full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse.trading_reward_campaign_info', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse.trading_reward_pool_campaign_schedule', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_trade_reward_points', full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse.total_trade_reward_points', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_trading_reward_pool_campaign_schedule', full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse.pending_trading_reward_pool_campaign_schedule', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pending_total_trade_reward_points', full_name='injective.exchange.v1beta1.QueryTradeRewardCampaignResponse.pending_total_trade_reward_points', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7990,
  serialized_end=8489,
)


_QUERYISOPTEDOUTOFREWARDSREQUEST = _descriptor.Descriptor(
  name='QueryIsOptedOutOfRewardsRequest',
  full_name='injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8491,
  serialized_end=8541,
)


_QUERYISOPTEDOUTOFREWARDSRESPONSE = _descriptor.Descriptor(
  name='QueryIsOptedOutOfRewardsResponse',
  full_name='injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_opted_out', full_name='injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse.is_opted_out', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8543,
  serialized_end=8599,
)


_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST = _descriptor.Descriptor(
  name='QueryOptedOutOfRewardsAccountsRequest',
  full_name='injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8601,
  serialized_end=8640,
)


_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE = _descriptor.Descriptor(
  name='QueryOptedOutOfRewardsAccountsResponse',
  full_name='injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='accounts', full_name='injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse.accounts', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8642,
  serialized_end=8700,
)


_QUERYFEEDISCOUNTACCOUNTINFOREQUEST = _descriptor.Descriptor(
  name='QueryFeeDiscountAccountInfoRequest',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest.account', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8702,
  serialized_end=8755,
)


_QUERYFEEDISCOUNTACCOUNTINFORESPONSE = _descriptor.Descriptor(
  name='QueryFeeDiscountAccountInfoResponse',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tier_level', full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse.tier_level', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_info', full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse.account_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_ttl', full_name='injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse.account_ttl', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8758,
  serialized_end=8955,
)


_QUERYFEEDISCOUNTSCHEDULEREQUEST = _descriptor.Descriptor(
  name='QueryFeeDiscountScheduleRequest',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8957,
  serialized_end=8990,
)


_QUERYFEEDISCOUNTSCHEDULERESPONSE = _descriptor.Descriptor(
  name='QueryFeeDiscountScheduleResponse',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fee_discount_schedule', full_name='injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse.fee_discount_schedule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8992,
  serialized_end=9106,
)


_QUERYBALANCEMISMATCHESREQUEST = _descriptor.Descriptor(
  name='QueryBalanceMismatchesRequest',
  full_name='injective.exchange.v1beta1.QueryBalanceMismatchesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dust_factor', full_name='injective.exchange.v1beta1.QueryBalanceMismatchesRequest.dust_factor', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9108,
  serialized_end=9160,
)


_BALANCEMISMATCH = _descriptor.Descriptor(
  name='BalanceMismatch',
  full_name='injective.exchange.v1beta1.BalanceMismatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccountId', full_name='injective.exchange.v1beta1.BalanceMismatch.subaccountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.BalanceMismatch.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='injective.exchange.v1beta1.BalanceMismatch.available', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='injective.exchange.v1beta1.BalanceMismatch.total', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_hold', full_name='injective.exchange.v1beta1.BalanceMismatch.balance_hold', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_total', full_name='injective.exchange.v1beta1.BalanceMismatch.expected_total', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='difference', full_name='injective.exchange.v1beta1.BalanceMismatch.difference', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9163,
  serialized_end=9557,
)


_QUERYBALANCEMISMATCHESRESPONSE = _descriptor.Descriptor(
  name='QueryBalanceMismatchesResponse',
  full_name='injective.exchange.v1beta1.QueryBalanceMismatchesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance_mismatches', full_name='injective.exchange.v1beta1.QueryBalanceMismatchesResponse.balance_mismatches', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9559,
  serialized_end=9664,
)


_QUERYBALANCEWITHBALANCEHOLDSREQUEST = _descriptor.Descriptor(
  name='QueryBalanceWithBalanceHoldsRequest',
  full_name='injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9666,
  serialized_end=9703,
)


_BALANCEWITHMARGINHOLD = _descriptor.Descriptor(
  name='BalanceWithMarginHold',
  full_name='injective.exchange.v1beta1.BalanceWithMarginHold',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccountId', full_name='injective.exchange.v1beta1.BalanceWithMarginHold.subaccountId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='denom', full_name='injective.exchange.v1beta1.BalanceWithMarginHold.denom', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='available', full_name='injective.exchange.v1beta1.BalanceWithMarginHold.available', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total', full_name='injective.exchange.v1beta1.BalanceWithMarginHold.total', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance_hold', full_name='injective.exchange.v1beta1.BalanceWithMarginHold.balance_hold', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9706,
  serialized_end=9966,
)


_QUERYBALANCEWITHBALANCEHOLDSRESPONSE = _descriptor.Descriptor(
  name='QueryBalanceWithBalanceHoldsResponse',
  full_name='injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance_with_balance_holds', full_name='injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse.balance_with_balance_holds', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9968,
  serialized_end=10093,
)


_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST = _descriptor.Descriptor(
  name='QueryFeeDiscountTierStatisticsRequest',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10095,
  serialized_end=10134,
)


_TIERSTATISTIC = _descriptor.Descriptor(
  name='TierStatistic',
  full_name='injective.exchange.v1beta1.TierStatistic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tier', full_name='injective.exchange.v1beta1.TierStatistic.tier', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='injective.exchange.v1beta1.TierStatistic.count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10136,
  serialized_end=10180,
)


_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE = _descriptor.Descriptor(
  name='QueryFeeDiscountTierStatisticsResponse',
  full_name='injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='statistics', full_name='injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse.statistics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10182,
  serialized_end=10285,
)


_NINJAVAULTINFOSREQUEST = _descriptor.Descriptor(
  name='NinjaVaultInfosRequest',
  full_name='injective.exchange.v1beta1.NinjaVaultInfosRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10287,
  serialized_end=10311,
)


_NINJAVAULTINFOSRESPONSE = _descriptor.Descriptor(
  name='NinjaVaultInfosResponse',
  full_name='injective.exchange.v1beta1.NinjaVaultInfosResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='master_addresses', full_name='injective.exchange.v1beta1.NinjaVaultInfosResponse.master_addresses', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='derivative_addresses', full_name='injective.exchange.v1beta1.NinjaVaultInfosResponse.derivative_addresses', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='spot_addresses', full_name='injective.exchange.v1beta1.NinjaVaultInfosResponse.spot_addresses', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cw20_addresses', full_name='injective.exchange.v1beta1.NinjaVaultInfosResponse.cw20_addresses', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10314,
  serialized_end=10443,
)


_QUERYMARKETIDFROMVAULTREQUEST = _descriptor.Descriptor(
  name='QueryMarketIDFromVaultRequest',
  full_name='injective.exchange.v1beta1.QueryMarketIDFromVaultRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vault_subaccount_id', full_name='injective.exchange.v1beta1.QueryMarketIDFromVaultRequest.vault_subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10445,
  serialized_end=10505,
)


_QUERYMARKETIDFROMVAULTRESPONSE = _descriptor.Descriptor(
  name='QueryMarketIDFromVaultResponse',
  full_name='injective.exchange.v1beta1.QueryMarketIDFromVaultResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryMarketIDFromVaultResponse.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10507,
  serialized_end=10558,
)


_QUERYHISTORICALTRADERECORDSREQUEST = _descriptor.Descriptor(
  name='QueryHistoricalTradeRecordsRequest',
  full_name='injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10560,
  serialized_end=10615,
)


_QUERYHISTORICALTRADERECORDSRESPONSE = _descriptor.Descriptor(
  name='QueryHistoricalTradeRecordsResponse',
  full_name='injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_records', full_name='injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse.trade_records', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10617,
  serialized_end=10719,
)


_TRADEHISTORYOPTIONS = _descriptor.Descriptor(
  name='TradeHistoryOptions',
  full_name='injective.exchange.v1beta1.TradeHistoryOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='trade_grouping_sec', full_name='injective.exchange.v1beta1.TradeHistoryOptions.trade_grouping_sec', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_age', full_name='injective.exchange.v1beta1.TradeHistoryOptions.max_age', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_raw_history', full_name='injective.exchange.v1beta1.TradeHistoryOptions.include_raw_history', index=2,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='include_metadata', full_name='injective.exchange.v1beta1.TradeHistoryOptions.include_metadata', index=3,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10721,
  serialized_end=10842,
)


_QUERYMARKETVOLATILITYREQUEST = _descriptor.Descriptor(
  name='QueryMarketVolatilityRequest',
  full_name='injective.exchange.v1beta1.QueryMarketVolatilityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryMarketVolatilityRequest.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trade_history_options', full_name='injective.exchange.v1beta1.QueryMarketVolatilityRequest.trade_history_options', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10845,
  serialized_end=10974,
)


_QUERYMARKETVOLATILITYRESPONSE = _descriptor.Descriptor(
  name='QueryMarketVolatilityResponse',
  full_name='injective.exchange.v1beta1.QueryMarketVolatilityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volatility', full_name='injective.exchange.v1beta1.QueryMarketVolatilityResponse.volatility', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='history_metadata', full_name='injective.exchange.v1beta1.QueryMarketVolatilityResponse.history_metadata', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='raw_history', full_name='injective.exchange.v1beta1.QueryMarketVolatilityResponse.raw_history', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10977,
  serialized_end=11206,
)


_QUERYBINARYMARKETSREQUEST = _descriptor.Descriptor(
  name='QueryBinaryMarketsRequest',
  full_name='injective.exchange.v1beta1.QueryBinaryMarketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='injective.exchange.v1beta1.QueryBinaryMarketsRequest.status', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11208,
  serialized_end=11251,
)


_QUERYBINARYMARKETSRESPONSE = _descriptor.Descriptor(
  name='QueryBinaryMarketsResponse',
  full_name='injective.exchange.v1beta1.QueryBinaryMarketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='markets', full_name='injective.exchange.v1beta1.QueryBinaryMarketsResponse.markets', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11253,
  serialized_end=11347,
)


_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST = _descriptor.Descriptor(
  name='QueryTraderDerivativeConditionalOrdersRequest',
  full_name='injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subaccount_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest.subaccount_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11349,
  serialized_end=11438,
)


_TRIMMEDDERIVATIVECONDITIONALORDER = _descriptor.Descriptor(
  name='TrimmedDerivativeConditionalOrder',
  full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='price', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.price', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantity', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.quantity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='margin', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.margin', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='triggerPrice', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.triggerPrice', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037&github.com/cosmos/cosmos-sdk/types.Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isBuy', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.isBuy', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\005isBuy', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isLimit', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.isLimit', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\352\336\037\007isLimit', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_hash', full_name='injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder.order_hash', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11441,
  serialized_end=11815,
)


_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE = _descriptor.Descriptor(
  name='QueryTraderDerivativeConditionalOrdersResponse',
  full_name='injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='orders', full_name='injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse.orders', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11817,
  serialized_end=11944,
)

_QUERYSUBACCOUNTORDERSRESPONSE.fields_by_name['buy_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTORDERDATA
_QUERYSUBACCOUNTORDERSRESPONSE.fields_by_name['sell_orders'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTORDERDATA
_SUBACCOUNTORDERBOOKMETADATAWITHMARKET.fields_by_name['metadata'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SUBACCOUNTORDERBOOKMETADATA
_QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PARAMS
_QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount'].message_type = _SUBACCOUNT
_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY.fields_by_name['value'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DEPOSIT
_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY.containing_type = _QUERYSUBACCOUNTDEPOSITSRESPONSE
_QUERYSUBACCOUNTDEPOSITSRESPONSE.fields_by_name['deposits'].message_type = _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY
_QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances'].message_type = injective_dot_exchange_dot_v1beta1_dot_genesis__pb2._BALANCE
_QUERYSUBACCOUNTDEPOSITRESPONSE.fields_by_name['deposits'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DEPOSIT
_QUERYSPOTMARKETSRESPONSE.fields_by_name['markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTMARKET
_QUERYSPOTMARKETRESPONSE.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._SPOTMARKET
_QUERYSPOTORDERBOOKRESPONSE.fields_by_name['buys_price_level'].message_type = _PRICELEVEL
_QUERYSPOTORDERBOOKRESPONSE.fields_by_name['sells_price_level'].message_type = _PRICELEVEL
_QUERYSPOTORDERSBYHASHESRESPONSE.fields_by_name['orders'].message_type = _TRIMMEDSPOTLIMITORDER
_QUERYTRADERSPOTORDERSRESPONSE.fields_by_name['orders'].message_type = _TRIMMEDSPOTLIMITORDER
_QUERYDERIVATIVEORDERBOOKRESPONSE.fields_by_name['buys_price_level'].message_type = _PRICELEVEL
_QUERYDERIVATIVEORDERBOOKRESPONSE.fields_by_name['sells_price_level'].message_type = _PRICELEVEL
_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['strategy'].enum_type = _CANCELLATIONSTRATEGY
_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['strategy'].enum_type = _CANCELLATIONSTRATEGY
_QUERYTRADERDERIVATIVEORDERSRESPONSE.fields_by_name['orders'].message_type = _TRIMMEDDERIVATIVELIMITORDER
_QUERYDERIVATIVEORDERSBYHASHESRESPONSE.fields_by_name['orders'].message_type = _TRIMMEDDERIVATIVELIMITORDER
_PERPETUALMARKETSTATE.fields_by_name['market_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETINFO
_PERPETUALMARKETSTATE.fields_by_name['funding_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
_FULLDERIVATIVEMARKET.fields_by_name['market'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._DERIVATIVEMARKET
_FULLDERIVATIVEMARKET.fields_by_name['perpetual_info'].message_type = _PERPETUALMARKETSTATE
_FULLDERIVATIVEMARKET.fields_by_name['futures_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXPIRYFUTURESMARKETINFO
_FULLDERIVATIVEMARKET.oneofs_by_name['info'].fields.append(
  _FULLDERIVATIVEMARKET.fields_by_name['perpetual_info'])
_FULLDERIVATIVEMARKET.fields_by_name['perpetual_info'].containing_oneof = _FULLDERIVATIVEMARKET.oneofs_by_name['info']
_FULLDERIVATIVEMARKET.oneofs_by_name['info'].fields.append(
  _FULLDERIVATIVEMARKET.fields_by_name['futures_info'])
_FULLDERIVATIVEMARKET.fields_by_name['futures_info'].containing_oneof = _FULLDERIVATIVEMARKET.oneofs_by_name['info']
_QUERYDERIVATIVEMARKETSRESPONSE.fields_by_name['markets'].message_type = _FULLDERIVATIVEMARKET
_QUERYDERIVATIVEMARKETRESPONSE.fields_by_name['market'].message_type = _FULLDERIVATIVEMARKET
_QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state'].message_type = injective_dot_exchange_dot_v1beta1_dot_genesis__pb2._DERIVATIVEPOSITION
_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._POSITION
_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state'].message_type = _EFFECTIVEPOSITION
_QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETINFO
_QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._EXPIRYFUTURESMARKETINFO
_QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._PERPETUALMARKETFUNDING
_QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata'].message_type = _SUBACCOUNTORDERBOOKMETADATAWITHMARKET
_QUERYMODULESTATERESPONSE.fields_by_name['state'].message_type = injective_dot_exchange_dot_v1beta1_dot_genesis__pb2._GENESISSTATE
_QUERYPOSITIONSRESPONSE.fields_by_name['state'].message_type = injective_dot_exchange_dot_v1beta1_dot_genesis__pb2._DERIVATIVEPOSITION
_QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['trading_reward_campaign_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADINGREWARDCAMPAIGNINFO
_QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_trading_reward_pool_campaign_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._CAMPAIGNREWARDPOOL
_QUERYFEEDISCOUNTACCOUNTINFORESPONSE.fields_by_name['account_info'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTTIERINFO
_QUERYFEEDISCOUNTACCOUNTINFORESPONSE.fields_by_name['account_ttl'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTTIERTTL
_QUERYFEEDISCOUNTSCHEDULERESPONSE.fields_by_name['fee_discount_schedule'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._FEEDISCOUNTSCHEDULE
_QUERYBALANCEMISMATCHESRESPONSE.fields_by_name['balance_mismatches'].message_type = _BALANCEMISMATCH
_QUERYBALANCEWITHBALANCEHOLDSRESPONSE.fields_by_name['balance_with_balance_holds'].message_type = _BALANCEWITHMARGINHOLD
_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE.fields_by_name['statistics'].message_type = _TIERSTATISTIC
_QUERYHISTORICALTRADERECORDSRESPONSE.fields_by_name['trade_records'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADERECORDS
_QUERYMARKETVOLATILITYREQUEST.fields_by_name['trade_history_options'].message_type = _TRADEHISTORYOPTIONS
_QUERYMARKETVOLATILITYRESPONSE.fields_by_name['history_metadata'].message_type = injective_dot_oracle_dot_v1beta1_dot_oracle__pb2._METADATASTATISTICS
_QUERYMARKETVOLATILITYRESPONSE.fields_by_name['raw_history'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._TRADERECORD
_QUERYBINARYMARKETSRESPONSE.fields_by_name['markets'].message_type = injective_dot_exchange_dot_v1beta1_dot_exchange__pb2._BINARYOPTIONSMARKET
_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE.fields_by_name['orders'].message_type = _TRIMMEDDERIVATIVECONDITIONALORDER
DESCRIPTOR.message_types_by_name['Subaccount'] = _SUBACCOUNT
DESCRIPTOR.message_types_by_name['QuerySubaccountOrdersRequest'] = _QUERYSUBACCOUNTORDERSREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountOrdersResponse'] = _QUERYSUBACCOUNTORDERSRESPONSE
DESCRIPTOR.message_types_by_name['SubaccountOrderbookMetadataWithMarket'] = _SUBACCOUNTORDERBOOKMETADATAWITHMARKET
DESCRIPTOR.message_types_by_name['QueryExchangeParamsRequest'] = _QUERYEXCHANGEPARAMSREQUEST
DESCRIPTOR.message_types_by_name['QueryExchangeParamsResponse'] = _QUERYEXCHANGEPARAMSRESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountDepositsRequest'] = _QUERYSUBACCOUNTDEPOSITSREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountDepositsResponse'] = _QUERYSUBACCOUNTDEPOSITSRESPONSE
DESCRIPTOR.message_types_by_name['QueryExchangeBalancesRequest'] = _QUERYEXCHANGEBALANCESREQUEST
DESCRIPTOR.message_types_by_name['QueryExchangeBalancesResponse'] = _QUERYEXCHANGEBALANCESRESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountDepositRequest'] = _QUERYSUBACCOUNTDEPOSITREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountDepositResponse'] = _QUERYSUBACCOUNTDEPOSITRESPONSE
DESCRIPTOR.message_types_by_name['QuerySpotMarketsRequest'] = _QUERYSPOTMARKETSREQUEST
DESCRIPTOR.message_types_by_name['QuerySpotMarketsResponse'] = _QUERYSPOTMARKETSRESPONSE
DESCRIPTOR.message_types_by_name['QuerySpotMarketRequest'] = _QUERYSPOTMARKETREQUEST
DESCRIPTOR.message_types_by_name['QuerySpotMarketResponse'] = _QUERYSPOTMARKETRESPONSE
DESCRIPTOR.message_types_by_name['QuerySpotOrderbookRequest'] = _QUERYSPOTORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['QuerySpotOrderbookResponse'] = _QUERYSPOTORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['QuerySpotOrdersByHashesRequest'] = _QUERYSPOTORDERSBYHASHESREQUEST
DESCRIPTOR.message_types_by_name['QuerySpotOrdersByHashesResponse'] = _QUERYSPOTORDERSBYHASHESRESPONSE
DESCRIPTOR.message_types_by_name['QueryTraderSpotOrdersRequest'] = _QUERYTRADERSPOTORDERSREQUEST
DESCRIPTOR.message_types_by_name['TrimmedSpotLimitOrder'] = _TRIMMEDSPOTLIMITORDER
DESCRIPTOR.message_types_by_name['QueryTraderSpotOrdersResponse'] = _QUERYTRADERSPOTORDERSRESPONSE
DESCRIPTOR.message_types_by_name['QuerySpotMidPriceAndTOBRequest'] = _QUERYSPOTMIDPRICEANDTOBREQUEST
DESCRIPTOR.message_types_by_name['QuerySpotMidPriceAndTOBResponse'] = _QUERYSPOTMIDPRICEANDTOBRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeMidPriceAndTOBRequest'] = _QUERYDERIVATIVEMIDPRICEANDTOBREQUEST
DESCRIPTOR.message_types_by_name['QueryDerivativeMidPriceAndTOBResponse'] = _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeOrderbookRequest'] = _QUERYDERIVATIVEORDERBOOKREQUEST
DESCRIPTOR.message_types_by_name['QueryDerivativeOrderbookResponse'] = _QUERYDERIVATIVEORDERBOOKRESPONSE
DESCRIPTOR.message_types_by_name['QueryTraderSpotOrdersToCancelUpToAmountRequest'] = _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST
DESCRIPTOR.message_types_by_name['QueryTraderDerivativeOrdersToCancelUpToAmountRequest'] = _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST
DESCRIPTOR.message_types_by_name['QueryTraderDerivativeOrdersRequest'] = _QUERYTRADERDERIVATIVEORDERSREQUEST
DESCRIPTOR.message_types_by_name['TrimmedDerivativeLimitOrder'] = _TRIMMEDDERIVATIVELIMITORDER
DESCRIPTOR.message_types_by_name['QueryTraderDerivativeOrdersResponse'] = _QUERYTRADERDERIVATIVEORDERSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeOrdersByHashesRequest'] = _QUERYDERIVATIVEORDERSBYHASHESREQUEST
DESCRIPTOR.message_types_by_name['QueryDerivativeOrdersByHashesResponse'] = _QUERYDERIVATIVEORDERSBYHASHESRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketsRequest'] = _QUERYDERIVATIVEMARKETSREQUEST
DESCRIPTOR.message_types_by_name['PriceLevel'] = _PRICELEVEL
DESCRIPTOR.message_types_by_name['PerpetualMarketState'] = _PERPETUALMARKETSTATE
DESCRIPTOR.message_types_by_name['FullDerivativeMarket'] = _FULLDERIVATIVEMARKET
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketsResponse'] = _QUERYDERIVATIVEMARKETSRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketRequest'] = _QUERYDERIVATIVEMARKETREQUEST
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketResponse'] = _QUERYDERIVATIVEMARKETRESPONSE
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketAddressRequest'] = _QUERYDERIVATIVEMARKETADDRESSREQUEST
DESCRIPTOR.message_types_by_name['QueryDerivativeMarketAddressResponse'] = _QUERYDERIVATIVEMARKETADDRESSRESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountTradeNonceRequest'] = _QUERYSUBACCOUNTTRADENONCEREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountPositionsRequest'] = _QUERYSUBACCOUNTPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountPositionInMarketRequest'] = _QUERYSUBACCOUNTPOSITIONINMARKETREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountEffectivePositionInMarketRequest'] = _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountOrderMetadataRequest'] = _QUERYSUBACCOUNTORDERMETADATAREQUEST
DESCRIPTOR.message_types_by_name['QuerySubaccountPositionsResponse'] = _QUERYSUBACCOUNTPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountPositionInMarketResponse'] = _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE
DESCRIPTOR.message_types_by_name['EffectivePosition'] = _EFFECTIVEPOSITION
DESCRIPTOR.message_types_by_name['QuerySubaccountEffectivePositionInMarketResponse'] = _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE
DESCRIPTOR.message_types_by_name['QueryPerpetualMarketInfoRequest'] = _QUERYPERPETUALMARKETINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryPerpetualMarketInfoResponse'] = _QUERYPERPETUALMARKETINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryExpiryFuturesMarketInfoRequest'] = _QUERYEXPIRYFUTURESMARKETINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryExpiryFuturesMarketInfoResponse'] = _QUERYEXPIRYFUTURESMARKETINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryPerpetualMarketFundingRequest'] = _QUERYPERPETUALMARKETFUNDINGREQUEST
DESCRIPTOR.message_types_by_name['QueryPerpetualMarketFundingResponse'] = _QUERYPERPETUALMARKETFUNDINGRESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountOrderMetadataResponse'] = _QUERYSUBACCOUNTORDERMETADATARESPONSE
DESCRIPTOR.message_types_by_name['QuerySubaccountTradeNonceResponse'] = _QUERYSUBACCOUNTTRADENONCERESPONSE
DESCRIPTOR.message_types_by_name['QueryModuleStateRequest'] = _QUERYMODULESTATEREQUEST
DESCRIPTOR.message_types_by_name['QueryModuleStateResponse'] = _QUERYMODULESTATERESPONSE
DESCRIPTOR.message_types_by_name['QueryPositionsRequest'] = _QUERYPOSITIONSREQUEST
DESCRIPTOR.message_types_by_name['QueryPositionsResponse'] = _QUERYPOSITIONSRESPONSE
DESCRIPTOR.message_types_by_name['QueryTradeRewardPointsRequest'] = _QUERYTRADEREWARDPOINTSREQUEST
DESCRIPTOR.message_types_by_name['QueryTradeRewardPointsResponse'] = _QUERYTRADEREWARDPOINTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryTradeRewardCampaignRequest'] = _QUERYTRADEREWARDCAMPAIGNREQUEST
DESCRIPTOR.message_types_by_name['QueryTradeRewardCampaignResponse'] = _QUERYTRADEREWARDCAMPAIGNRESPONSE
DESCRIPTOR.message_types_by_name['QueryIsOptedOutOfRewardsRequest'] = _QUERYISOPTEDOUTOFREWARDSREQUEST
DESCRIPTOR.message_types_by_name['QueryIsOptedOutOfRewardsResponse'] = _QUERYISOPTEDOUTOFREWARDSRESPONSE
DESCRIPTOR.message_types_by_name['QueryOptedOutOfRewardsAccountsRequest'] = _QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST
DESCRIPTOR.message_types_by_name['QueryOptedOutOfRewardsAccountsResponse'] = _QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeeDiscountAccountInfoRequest'] = _QUERYFEEDISCOUNTACCOUNTINFOREQUEST
DESCRIPTOR.message_types_by_name['QueryFeeDiscountAccountInfoResponse'] = _QUERYFEEDISCOUNTACCOUNTINFORESPONSE
DESCRIPTOR.message_types_by_name['QueryFeeDiscountScheduleRequest'] = _QUERYFEEDISCOUNTSCHEDULEREQUEST
DESCRIPTOR.message_types_by_name['QueryFeeDiscountScheduleResponse'] = _QUERYFEEDISCOUNTSCHEDULERESPONSE
DESCRIPTOR.message_types_by_name['QueryBalanceMismatchesRequest'] = _QUERYBALANCEMISMATCHESREQUEST
DESCRIPTOR.message_types_by_name['BalanceMismatch'] = _BALANCEMISMATCH
DESCRIPTOR.message_types_by_name['QueryBalanceMismatchesResponse'] = _QUERYBALANCEMISMATCHESRESPONSE
DESCRIPTOR.message_types_by_name['QueryBalanceWithBalanceHoldsRequest'] = _QUERYBALANCEWITHBALANCEHOLDSREQUEST
DESCRIPTOR.message_types_by_name['BalanceWithMarginHold'] = _BALANCEWITHMARGINHOLD
DESCRIPTOR.message_types_by_name['QueryBalanceWithBalanceHoldsResponse'] = _QUERYBALANCEWITHBALANCEHOLDSRESPONSE
DESCRIPTOR.message_types_by_name['QueryFeeDiscountTierStatisticsRequest'] = _QUERYFEEDISCOUNTTIERSTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['TierStatistic'] = _TIERSTATISTIC
DESCRIPTOR.message_types_by_name['QueryFeeDiscountTierStatisticsResponse'] = _QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE
DESCRIPTOR.message_types_by_name['NinjaVaultInfosRequest'] = _NINJAVAULTINFOSREQUEST
DESCRIPTOR.message_types_by_name['NinjaVaultInfosResponse'] = _NINJAVAULTINFOSRESPONSE
DESCRIPTOR.message_types_by_name['QueryMarketIDFromVaultRequest'] = _QUERYMARKETIDFROMVAULTREQUEST
DESCRIPTOR.message_types_by_name['QueryMarketIDFromVaultResponse'] = _QUERYMARKETIDFROMVAULTRESPONSE
DESCRIPTOR.message_types_by_name['QueryHistoricalTradeRecordsRequest'] = _QUERYHISTORICALTRADERECORDSREQUEST
DESCRIPTOR.message_types_by_name['QueryHistoricalTradeRecordsResponse'] = _QUERYHISTORICALTRADERECORDSRESPONSE
DESCRIPTOR.message_types_by_name['TradeHistoryOptions'] = _TRADEHISTORYOPTIONS
DESCRIPTOR.message_types_by_name['QueryMarketVolatilityRequest'] = _QUERYMARKETVOLATILITYREQUEST
DESCRIPTOR.message_types_by_name['QueryMarketVolatilityResponse'] = _QUERYMARKETVOLATILITYRESPONSE
DESCRIPTOR.message_types_by_name['QueryBinaryMarketsRequest'] = _QUERYBINARYMARKETSREQUEST
DESCRIPTOR.message_types_by_name['QueryBinaryMarketsResponse'] = _QUERYBINARYMARKETSRESPONSE
DESCRIPTOR.message_types_by_name['QueryTraderDerivativeConditionalOrdersRequest'] = _QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST
DESCRIPTOR.message_types_by_name['TrimmedDerivativeConditionalOrder'] = _TRIMMEDDERIVATIVECONDITIONALORDER
DESCRIPTOR.message_types_by_name['QueryTraderDerivativeConditionalOrdersResponse'] = _QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE
DESCRIPTOR.enum_types_by_name['CancellationStrategy'] = _CANCELLATIONSTRATEGY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subaccount = _reflection.GeneratedProtocolMessageType('Subaccount', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNT,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.Subaccount)
  })
_sym_db.RegisterMessage(Subaccount)

QuerySubaccountOrdersRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTORDERSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountOrdersRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountOrdersRequest)

QuerySubaccountOrdersResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountOrdersResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountOrdersResponse)

SubaccountOrderbookMetadataWithMarket = _reflection.GeneratedProtocolMessageType('SubaccountOrderbookMetadataWithMarket', (_message.Message,), {
  'DESCRIPTOR' : _SUBACCOUNTORDERBOOKMETADATAWITHMARKET,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.SubaccountOrderbookMetadataWithMarket)
  })
_sym_db.RegisterMessage(SubaccountOrderbookMetadataWithMarket)

QueryExchangeParamsRequest = _reflection.GeneratedProtocolMessageType('QueryExchangeParamsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGEPARAMSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExchangeParamsRequest)
  })
_sym_db.RegisterMessage(QueryExchangeParamsRequest)

QueryExchangeParamsResponse = _reflection.GeneratedProtocolMessageType('QueryExchangeParamsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGEPARAMSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExchangeParamsResponse)
  })
_sym_db.RegisterMessage(QueryExchangeParamsResponse)

QuerySubaccountDepositsRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountDepositsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTDEPOSITSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountDepositsRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountDepositsRequest)

QuerySubaccountDepositsResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountDepositsResponse', (_message.Message,), {

  'DepositsEntry' : _reflection.GeneratedProtocolMessageType('DepositsEntry', (_message.Message,), {
    'DESCRIPTOR' : _QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY,
    '__module__' : 'injective.exchange.v1beta1.query_pb2'
    # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountDepositsResponse.DepositsEntry)
    })
  ,
  'DESCRIPTOR' : _QUERYSUBACCOUNTDEPOSITSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountDepositsResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountDepositsResponse)
_sym_db.RegisterMessage(QuerySubaccountDepositsResponse.DepositsEntry)

QueryExchangeBalancesRequest = _reflection.GeneratedProtocolMessageType('QueryExchangeBalancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGEBALANCESREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExchangeBalancesRequest)
  })
_sym_db.RegisterMessage(QueryExchangeBalancesRequest)

QueryExchangeBalancesResponse = _reflection.GeneratedProtocolMessageType('QueryExchangeBalancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXCHANGEBALANCESRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExchangeBalancesResponse)
  })
_sym_db.RegisterMessage(QueryExchangeBalancesResponse)

QuerySubaccountDepositRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountDepositRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTDEPOSITREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountDepositRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountDepositRequest)

QuerySubaccountDepositResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountDepositResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTDEPOSITRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountDepositResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountDepositResponse)

QuerySpotMarketsRequest = _reflection.GeneratedProtocolMessageType('QuerySpotMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMARKETSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMarketsRequest)
  })
_sym_db.RegisterMessage(QuerySpotMarketsRequest)

QuerySpotMarketsResponse = _reflection.GeneratedProtocolMessageType('QuerySpotMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMARKETSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMarketsResponse)
  })
_sym_db.RegisterMessage(QuerySpotMarketsResponse)

QuerySpotMarketRequest = _reflection.GeneratedProtocolMessageType('QuerySpotMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMARKETREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMarketRequest)
  })
_sym_db.RegisterMessage(QuerySpotMarketRequest)

QuerySpotMarketResponse = _reflection.GeneratedProtocolMessageType('QuerySpotMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMARKETRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMarketResponse)
  })
_sym_db.RegisterMessage(QuerySpotMarketResponse)

QuerySpotOrderbookRequest = _reflection.GeneratedProtocolMessageType('QuerySpotOrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTORDERBOOKREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotOrderbookRequest)
  })
_sym_db.RegisterMessage(QuerySpotOrderbookRequest)

QuerySpotOrderbookResponse = _reflection.GeneratedProtocolMessageType('QuerySpotOrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTORDERBOOKRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotOrderbookResponse)
  })
_sym_db.RegisterMessage(QuerySpotOrderbookResponse)

QuerySpotOrdersByHashesRequest = _reflection.GeneratedProtocolMessageType('QuerySpotOrdersByHashesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTORDERSBYHASHESREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotOrdersByHashesRequest)
  })
_sym_db.RegisterMessage(QuerySpotOrdersByHashesRequest)

QuerySpotOrdersByHashesResponse = _reflection.GeneratedProtocolMessageType('QuerySpotOrdersByHashesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTORDERSBYHASHESRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotOrdersByHashesResponse)
  })
_sym_db.RegisterMessage(QuerySpotOrdersByHashesResponse)

QueryTraderSpotOrdersRequest = _reflection.GeneratedProtocolMessageType('QueryTraderSpotOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERSPOTORDERSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderSpotOrdersRequest)
  })
_sym_db.RegisterMessage(QueryTraderSpotOrdersRequest)

TrimmedSpotLimitOrder = _reflection.GeneratedProtocolMessageType('TrimmedSpotLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _TRIMMEDSPOTLIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TrimmedSpotLimitOrder)
  })
_sym_db.RegisterMessage(TrimmedSpotLimitOrder)

QueryTraderSpotOrdersResponse = _reflection.GeneratedProtocolMessageType('QueryTraderSpotOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERSPOTORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderSpotOrdersResponse)
  })
_sym_db.RegisterMessage(QueryTraderSpotOrdersResponse)

QuerySpotMidPriceAndTOBRequest = _reflection.GeneratedProtocolMessageType('QuerySpotMidPriceAndTOBRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMIDPRICEANDTOBREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMidPriceAndTOBRequest)
  })
_sym_db.RegisterMessage(QuerySpotMidPriceAndTOBRequest)

QuerySpotMidPriceAndTOBResponse = _reflection.GeneratedProtocolMessageType('QuerySpotMidPriceAndTOBResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSPOTMIDPRICEANDTOBRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySpotMidPriceAndTOBResponse)
  })
_sym_db.RegisterMessage(QuerySpotMidPriceAndTOBResponse)

QueryDerivativeMidPriceAndTOBRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeMidPriceAndTOBRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMIDPRICEANDTOBREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeMidPriceAndTOBRequest)

QueryDerivativeMidPriceAndTOBResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeMidPriceAndTOBResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMidPriceAndTOBResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeMidPriceAndTOBResponse)

QueryDerivativeOrderbookRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeOrderbookRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEORDERBOOKREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeOrderbookRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeOrderbookRequest)

QueryDerivativeOrderbookResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeOrderbookResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEORDERBOOKRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeOrderbookResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeOrderbookResponse)

QueryTraderSpotOrdersToCancelUpToAmountRequest = _reflection.GeneratedProtocolMessageType('QueryTraderSpotOrdersToCancelUpToAmountRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderSpotOrdersToCancelUpToAmountRequest)
  })
_sym_db.RegisterMessage(QueryTraderSpotOrdersToCancelUpToAmountRequest)

QueryTraderDerivativeOrdersToCancelUpToAmountRequest = _reflection.GeneratedProtocolMessageType('QueryTraderDerivativeOrdersToCancelUpToAmountRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderDerivativeOrdersToCancelUpToAmountRequest)
  })
_sym_db.RegisterMessage(QueryTraderDerivativeOrdersToCancelUpToAmountRequest)

QueryTraderDerivativeOrdersRequest = _reflection.GeneratedProtocolMessageType('QueryTraderDerivativeOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERDERIVATIVEORDERSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderDerivativeOrdersRequest)
  })
_sym_db.RegisterMessage(QueryTraderDerivativeOrdersRequest)

TrimmedDerivativeLimitOrder = _reflection.GeneratedProtocolMessageType('TrimmedDerivativeLimitOrder', (_message.Message,), {
  'DESCRIPTOR' : _TRIMMEDDERIVATIVELIMITORDER,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TrimmedDerivativeLimitOrder)
  })
_sym_db.RegisterMessage(TrimmedDerivativeLimitOrder)

QueryTraderDerivativeOrdersResponse = _reflection.GeneratedProtocolMessageType('QueryTraderDerivativeOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERDERIVATIVEORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderDerivativeOrdersResponse)
  })
_sym_db.RegisterMessage(QueryTraderDerivativeOrdersResponse)

QueryDerivativeOrdersByHashesRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeOrdersByHashesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEORDERSBYHASHESREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeOrdersByHashesRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeOrdersByHashesRequest)

QueryDerivativeOrdersByHashesResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeOrdersByHashesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEORDERSBYHASHESRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeOrdersByHashesResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeOrdersByHashesResponse)

QueryDerivativeMarketsRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketsRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketsRequest)

PriceLevel = _reflection.GeneratedProtocolMessageType('PriceLevel', (_message.Message,), {
  'DESCRIPTOR' : _PRICELEVEL,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PriceLevel)
  })
_sym_db.RegisterMessage(PriceLevel)

PerpetualMarketState = _reflection.GeneratedProtocolMessageType('PerpetualMarketState', (_message.Message,), {
  'DESCRIPTOR' : _PERPETUALMARKETSTATE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.PerpetualMarketState)
  })
_sym_db.RegisterMessage(PerpetualMarketState)

FullDerivativeMarket = _reflection.GeneratedProtocolMessageType('FullDerivativeMarket', (_message.Message,), {
  'DESCRIPTOR' : _FULLDERIVATIVEMARKET,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.FullDerivativeMarket)
  })
_sym_db.RegisterMessage(FullDerivativeMarket)

QueryDerivativeMarketsResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketsResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketsResponse)

QueryDerivativeMarketRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketRequest)

QueryDerivativeMarketResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketResponse)

QueryDerivativeMarketAddressRequest = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketAddressRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETADDRESSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketAddressRequest)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketAddressRequest)

QueryDerivativeMarketAddressResponse = _reflection.GeneratedProtocolMessageType('QueryDerivativeMarketAddressResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYDERIVATIVEMARKETADDRESSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryDerivativeMarketAddressResponse)
  })
_sym_db.RegisterMessage(QueryDerivativeMarketAddressResponse)

QuerySubaccountTradeNonceRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountTradeNonceRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTTRADENONCEREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountTradeNonceRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountTradeNonceRequest)

QuerySubaccountPositionsRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTPOSITIONSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountPositionsRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountPositionsRequest)

QuerySubaccountPositionInMarketRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountPositionInMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTPOSITIONINMARKETREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountPositionInMarketRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountPositionInMarketRequest)

QuerySubaccountEffectivePositionInMarketRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountEffectivePositionInMarketRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountEffectivePositionInMarketRequest)

QuerySubaccountOrderMetadataRequest = _reflection.GeneratedProtocolMessageType('QuerySubaccountOrderMetadataRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTORDERMETADATAREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountOrderMetadataRequest)
  })
_sym_db.RegisterMessage(QuerySubaccountOrderMetadataRequest)

QuerySubaccountPositionsResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTPOSITIONSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountPositionsResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountPositionsResponse)

QuerySubaccountPositionInMarketResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountPositionInMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountPositionInMarketResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountPositionInMarketResponse)

EffectivePosition = _reflection.GeneratedProtocolMessageType('EffectivePosition', (_message.Message,), {
  'DESCRIPTOR' : _EFFECTIVEPOSITION,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.EffectivePosition)
  })
_sym_db.RegisterMessage(EffectivePosition)

QuerySubaccountEffectivePositionInMarketResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountEffectivePositionInMarketResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountEffectivePositionInMarketResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountEffectivePositionInMarketResponse)

QueryPerpetualMarketInfoRequest = _reflection.GeneratedProtocolMessageType('QueryPerpetualMarketInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPERPETUALMARKETINFOREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPerpetualMarketInfoRequest)
  })
_sym_db.RegisterMessage(QueryPerpetualMarketInfoRequest)

QueryPerpetualMarketInfoResponse = _reflection.GeneratedProtocolMessageType('QueryPerpetualMarketInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPERPETUALMARKETINFORESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPerpetualMarketInfoResponse)
  })
_sym_db.RegisterMessage(QueryPerpetualMarketInfoResponse)

QueryExpiryFuturesMarketInfoRequest = _reflection.GeneratedProtocolMessageType('QueryExpiryFuturesMarketInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXPIRYFUTURESMARKETINFOREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoRequest)
  })
_sym_db.RegisterMessage(QueryExpiryFuturesMarketInfoRequest)

QueryExpiryFuturesMarketInfoResponse = _reflection.GeneratedProtocolMessageType('QueryExpiryFuturesMarketInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYEXPIRYFUTURESMARKETINFORESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryExpiryFuturesMarketInfoResponse)
  })
_sym_db.RegisterMessage(QueryExpiryFuturesMarketInfoResponse)

QueryPerpetualMarketFundingRequest = _reflection.GeneratedProtocolMessageType('QueryPerpetualMarketFundingRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPERPETUALMARKETFUNDINGREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPerpetualMarketFundingRequest)
  })
_sym_db.RegisterMessage(QueryPerpetualMarketFundingRequest)

QueryPerpetualMarketFundingResponse = _reflection.GeneratedProtocolMessageType('QueryPerpetualMarketFundingResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPERPETUALMARKETFUNDINGRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPerpetualMarketFundingResponse)
  })
_sym_db.RegisterMessage(QueryPerpetualMarketFundingResponse)

QuerySubaccountOrderMetadataResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountOrderMetadataResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTORDERMETADATARESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountOrderMetadataResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountOrderMetadataResponse)

QuerySubaccountTradeNonceResponse = _reflection.GeneratedProtocolMessageType('QuerySubaccountTradeNonceResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYSUBACCOUNTTRADENONCERESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QuerySubaccountTradeNonceResponse)
  })
_sym_db.RegisterMessage(QuerySubaccountTradeNonceResponse)

QueryModuleStateRequest = _reflection.GeneratedProtocolMessageType('QueryModuleStateRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATEREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryModuleStateRequest)
  })
_sym_db.RegisterMessage(QueryModuleStateRequest)

QueryModuleStateResponse = _reflection.GeneratedProtocolMessageType('QueryModuleStateResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMODULESTATERESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryModuleStateResponse)
  })
_sym_db.RegisterMessage(QueryModuleStateResponse)

QueryPositionsRequest = _reflection.GeneratedProtocolMessageType('QueryPositionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPositionsRequest)
  })
_sym_db.RegisterMessage(QueryPositionsRequest)

QueryPositionsResponse = _reflection.GeneratedProtocolMessageType('QueryPositionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYPOSITIONSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryPositionsResponse)
  })
_sym_db.RegisterMessage(QueryPositionsResponse)

QueryTradeRewardPointsRequest = _reflection.GeneratedProtocolMessageType('QueryTradeRewardPointsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADEREWARDPOINTSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTradeRewardPointsRequest)
  })
_sym_db.RegisterMessage(QueryTradeRewardPointsRequest)

QueryTradeRewardPointsResponse = _reflection.GeneratedProtocolMessageType('QueryTradeRewardPointsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADEREWARDPOINTSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTradeRewardPointsResponse)
  })
_sym_db.RegisterMessage(QueryTradeRewardPointsResponse)

QueryTradeRewardCampaignRequest = _reflection.GeneratedProtocolMessageType('QueryTradeRewardCampaignRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADEREWARDCAMPAIGNREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTradeRewardCampaignRequest)
  })
_sym_db.RegisterMessage(QueryTradeRewardCampaignRequest)

QueryTradeRewardCampaignResponse = _reflection.GeneratedProtocolMessageType('QueryTradeRewardCampaignResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADEREWARDCAMPAIGNRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTradeRewardCampaignResponse)
  })
_sym_db.RegisterMessage(QueryTradeRewardCampaignResponse)

QueryIsOptedOutOfRewardsRequest = _reflection.GeneratedProtocolMessageType('QueryIsOptedOutOfRewardsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYISOPTEDOUTOFREWARDSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryIsOptedOutOfRewardsRequest)
  })
_sym_db.RegisterMessage(QueryIsOptedOutOfRewardsRequest)

QueryIsOptedOutOfRewardsResponse = _reflection.GeneratedProtocolMessageType('QueryIsOptedOutOfRewardsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYISOPTEDOUTOFREWARDSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryIsOptedOutOfRewardsResponse)
  })
_sym_db.RegisterMessage(QueryIsOptedOutOfRewardsResponse)

QueryOptedOutOfRewardsAccountsRequest = _reflection.GeneratedProtocolMessageType('QueryOptedOutOfRewardsAccountsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsRequest)
  })
_sym_db.RegisterMessage(QueryOptedOutOfRewardsAccountsRequest)

QueryOptedOutOfRewardsAccountsResponse = _reflection.GeneratedProtocolMessageType('QueryOptedOutOfRewardsAccountsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryOptedOutOfRewardsAccountsResponse)
  })
_sym_db.RegisterMessage(QueryOptedOutOfRewardsAccountsResponse)

QueryFeeDiscountAccountInfoRequest = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountAccountInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTACCOUNTINFOREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountAccountInfoRequest)
  })
_sym_db.RegisterMessage(QueryFeeDiscountAccountInfoRequest)

QueryFeeDiscountAccountInfoResponse = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountAccountInfoResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTACCOUNTINFORESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountAccountInfoResponse)
  })
_sym_db.RegisterMessage(QueryFeeDiscountAccountInfoResponse)

QueryFeeDiscountScheduleRequest = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountScheduleRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTSCHEDULEREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountScheduleRequest)
  })
_sym_db.RegisterMessage(QueryFeeDiscountScheduleRequest)

QueryFeeDiscountScheduleResponse = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountScheduleResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTSCHEDULERESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountScheduleResponse)
  })
_sym_db.RegisterMessage(QueryFeeDiscountScheduleResponse)

QueryBalanceMismatchesRequest = _reflection.GeneratedProtocolMessageType('QueryBalanceMismatchesRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBALANCEMISMATCHESREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBalanceMismatchesRequest)
  })
_sym_db.RegisterMessage(QueryBalanceMismatchesRequest)

BalanceMismatch = _reflection.GeneratedProtocolMessageType('BalanceMismatch', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEMISMATCH,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BalanceMismatch)
  })
_sym_db.RegisterMessage(BalanceMismatch)

QueryBalanceMismatchesResponse = _reflection.GeneratedProtocolMessageType('QueryBalanceMismatchesResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBALANCEMISMATCHESRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBalanceMismatchesResponse)
  })
_sym_db.RegisterMessage(QueryBalanceMismatchesResponse)

QueryBalanceWithBalanceHoldsRequest = _reflection.GeneratedProtocolMessageType('QueryBalanceWithBalanceHoldsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBALANCEWITHBALANCEHOLDSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsRequest)
  })
_sym_db.RegisterMessage(QueryBalanceWithBalanceHoldsRequest)

BalanceWithMarginHold = _reflection.GeneratedProtocolMessageType('BalanceWithMarginHold', (_message.Message,), {
  'DESCRIPTOR' : _BALANCEWITHMARGINHOLD,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.BalanceWithMarginHold)
  })
_sym_db.RegisterMessage(BalanceWithMarginHold)

QueryBalanceWithBalanceHoldsResponse = _reflection.GeneratedProtocolMessageType('QueryBalanceWithBalanceHoldsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBALANCEWITHBALANCEHOLDSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBalanceWithBalanceHoldsResponse)
  })
_sym_db.RegisterMessage(QueryBalanceWithBalanceHoldsResponse)

QueryFeeDiscountTierStatisticsRequest = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountTierStatisticsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTTIERSTATISTICSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsRequest)
  })
_sym_db.RegisterMessage(QueryFeeDiscountTierStatisticsRequest)

TierStatistic = _reflection.GeneratedProtocolMessageType('TierStatistic', (_message.Message,), {
  'DESCRIPTOR' : _TIERSTATISTIC,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TierStatistic)
  })
_sym_db.RegisterMessage(TierStatistic)

QueryFeeDiscountTierStatisticsResponse = _reflection.GeneratedProtocolMessageType('QueryFeeDiscountTierStatisticsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryFeeDiscountTierStatisticsResponse)
  })
_sym_db.RegisterMessage(QueryFeeDiscountTierStatisticsResponse)

NinjaVaultInfosRequest = _reflection.GeneratedProtocolMessageType('NinjaVaultInfosRequest', (_message.Message,), {
  'DESCRIPTOR' : _NINJAVAULTINFOSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.NinjaVaultInfosRequest)
  })
_sym_db.RegisterMessage(NinjaVaultInfosRequest)

NinjaVaultInfosResponse = _reflection.GeneratedProtocolMessageType('NinjaVaultInfosResponse', (_message.Message,), {
  'DESCRIPTOR' : _NINJAVAULTINFOSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.NinjaVaultInfosResponse)
  })
_sym_db.RegisterMessage(NinjaVaultInfosResponse)

QueryMarketIDFromVaultRequest = _reflection.GeneratedProtocolMessageType('QueryMarketIDFromVaultRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETIDFROMVAULTREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryMarketIDFromVaultRequest)
  })
_sym_db.RegisterMessage(QueryMarketIDFromVaultRequest)

QueryMarketIDFromVaultResponse = _reflection.GeneratedProtocolMessageType('QueryMarketIDFromVaultResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETIDFROMVAULTRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryMarketIDFromVaultResponse)
  })
_sym_db.RegisterMessage(QueryMarketIDFromVaultResponse)

QueryHistoricalTradeRecordsRequest = _reflection.GeneratedProtocolMessageType('QueryHistoricalTradeRecordsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALTRADERECORDSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryHistoricalTradeRecordsRequest)
  })
_sym_db.RegisterMessage(QueryHistoricalTradeRecordsRequest)

QueryHistoricalTradeRecordsResponse = _reflection.GeneratedProtocolMessageType('QueryHistoricalTradeRecordsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORICALTRADERECORDSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryHistoricalTradeRecordsResponse)
  })
_sym_db.RegisterMessage(QueryHistoricalTradeRecordsResponse)

TradeHistoryOptions = _reflection.GeneratedProtocolMessageType('TradeHistoryOptions', (_message.Message,), {
  'DESCRIPTOR' : _TRADEHISTORYOPTIONS,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TradeHistoryOptions)
  })
_sym_db.RegisterMessage(TradeHistoryOptions)

QueryMarketVolatilityRequest = _reflection.GeneratedProtocolMessageType('QueryMarketVolatilityRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETVOLATILITYREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryMarketVolatilityRequest)
  })
_sym_db.RegisterMessage(QueryMarketVolatilityRequest)

QueryMarketVolatilityResponse = _reflection.GeneratedProtocolMessageType('QueryMarketVolatilityResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYMARKETVOLATILITYRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryMarketVolatilityResponse)
  })
_sym_db.RegisterMessage(QueryMarketVolatilityResponse)

QueryBinaryMarketsRequest = _reflection.GeneratedProtocolMessageType('QueryBinaryMarketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBINARYMARKETSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBinaryMarketsRequest)
  })
_sym_db.RegisterMessage(QueryBinaryMarketsRequest)

QueryBinaryMarketsResponse = _reflection.GeneratedProtocolMessageType('QueryBinaryMarketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYBINARYMARKETSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryBinaryMarketsResponse)
  })
_sym_db.RegisterMessage(QueryBinaryMarketsResponse)

QueryTraderDerivativeConditionalOrdersRequest = _reflection.GeneratedProtocolMessageType('QueryTraderDerivativeConditionalOrdersRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersRequest)
  })
_sym_db.RegisterMessage(QueryTraderDerivativeConditionalOrdersRequest)

TrimmedDerivativeConditionalOrder = _reflection.GeneratedProtocolMessageType('TrimmedDerivativeConditionalOrder', (_message.Message,), {
  'DESCRIPTOR' : _TRIMMEDDERIVATIVECONDITIONALORDER,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.TrimmedDerivativeConditionalOrder)
  })
_sym_db.RegisterMessage(TrimmedDerivativeConditionalOrder)

QueryTraderDerivativeConditionalOrdersResponse = _reflection.GeneratedProtocolMessageType('QueryTraderDerivativeConditionalOrdersResponse', (_message.Message,), {
  'DESCRIPTOR' : _QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE,
  '__module__' : 'injective.exchange.v1beta1.query_pb2'
  # @@protoc_insertion_point(class_scope:injective.exchange.v1beta1.QueryTraderDerivativeConditionalOrdersResponse)
  })
_sym_db.RegisterMessage(QueryTraderDerivativeConditionalOrdersResponse)


DESCRIPTOR._options = None
_QUERYEXCHANGEPARAMSRESPONSE.fields_by_name['params']._options = None
_QUERYSUBACCOUNTDEPOSITSREQUEST.fields_by_name['subaccount']._options = None
_QUERYSUBACCOUNTDEPOSITSRESPONSE_DEPOSITSENTRY._options = None
_QUERYEXCHANGEBALANCESRESPONSE.fields_by_name['balances']._options = None
_TRIMMEDSPOTLIMITORDER.fields_by_name['price']._options = None
_TRIMMEDSPOTLIMITORDER.fields_by_name['quantity']._options = None
_TRIMMEDSPOTLIMITORDER.fields_by_name['fillable']._options = None
_QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
_QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
_QUERYSPOTMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['mid_price']._options = None
_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_buy_price']._options = None
_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE.fields_by_name['best_sell_price']._options = None
_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['base_amount']._options = None
_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
_QUERYTRADERSPOTORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['quote_amount']._options = None
_QUERYTRADERDERIVATIVEORDERSTOCANCELUPTOAMOUNTREQUEST.fields_by_name['reference_price']._options = None
_TRIMMEDDERIVATIVELIMITORDER.fields_by_name['price']._options = None
_TRIMMEDDERIVATIVELIMITORDER.fields_by_name['quantity']._options = None
_TRIMMEDDERIVATIVELIMITORDER.fields_by_name['margin']._options = None
_TRIMMEDDERIVATIVELIMITORDER.fields_by_name['fillable']._options = None
_TRIMMEDDERIVATIVELIMITORDER.fields_by_name['isBuy']._options = None
_PRICELEVEL.fields_by_name['price']._options = None
_PRICELEVEL.fields_by_name['quantity']._options = None
_FULLDERIVATIVEMARKET.fields_by_name['mark_price']._options = None
_QUERYSUBACCOUNTPOSITIONSRESPONSE.fields_by_name['state']._options = None
_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
_EFFECTIVEPOSITION.fields_by_name['quantity']._options = None
_EFFECTIVEPOSITION.fields_by_name['entry_price']._options = None
_EFFECTIVEPOSITION.fields_by_name['effective_margin']._options = None
_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE.fields_by_name['state']._options = None
_QUERYPERPETUALMARKETINFORESPONSE.fields_by_name['info']._options = None
_QUERYEXPIRYFUTURESMARKETINFORESPONSE.fields_by_name['info']._options = None
_QUERYPERPETUALMARKETFUNDINGRESPONSE.fields_by_name['state']._options = None
_QUERYSUBACCOUNTORDERMETADATARESPONSE.fields_by_name['metadata']._options = None
_QUERYPOSITIONSRESPONSE.fields_by_name['state']._options = None
_QUERYTRADEREWARDPOINTSRESPONSE.fields_by_name['account_trade_reward_points']._options = None
_QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['total_trade_reward_points']._options = None
_QUERYTRADEREWARDCAMPAIGNRESPONSE.fields_by_name['pending_total_trade_reward_points']._options = None
_BALANCEMISMATCH.fields_by_name['available']._options = None
_BALANCEMISMATCH.fields_by_name['total']._options = None
_BALANCEMISMATCH.fields_by_name['balance_hold']._options = None
_BALANCEMISMATCH.fields_by_name['expected_total']._options = None
_BALANCEMISMATCH.fields_by_name['difference']._options = None
_BALANCEWITHMARGINHOLD.fields_by_name['available']._options = None
_BALANCEWITHMARGINHOLD.fields_by_name['total']._options = None
_BALANCEWITHMARGINHOLD.fields_by_name['balance_hold']._options = None
_QUERYMARKETVOLATILITYRESPONSE.fields_by_name['volatility']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['price']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['quantity']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['margin']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['triggerPrice']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isBuy']._options = None
_TRIMMEDDERIVATIVECONDITIONALORDER.fields_by_name['isLimit']._options = None

_QUERY = _descriptor.ServiceDescriptor(
  name='Query',
  full_name='injective.exchange.v1beta1.Query',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=12035,
  serialized_end=21993,
  methods=[
  _descriptor.MethodDescriptor(
    name='QueryExchangeParams',
    full_name='injective.exchange.v1beta1.Query.QueryExchangeParams',
    index=0,
    containing_service=None,
    input_type=_QUERYEXCHANGEPARAMSREQUEST,
    output_type=_QUERYEXCHANGEPARAMSRESPONSE,
    serialized_options=b'\202\323\344\223\002,\022*/injective/exchange/v1beta1/exchangeParams',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountDeposits',
    full_name='injective.exchange.v1beta1.Query.SubaccountDeposits',
    index=1,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTDEPOSITSREQUEST,
    output_type=_QUERYSUBACCOUNTDEPOSITSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/exchange/subaccountDeposits',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountDeposit',
    full_name='injective.exchange.v1beta1.Query.SubaccountDeposit',
    index=2,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTDEPOSITREQUEST,
    output_type=_QUERYSUBACCOUNTDEPOSITRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/exchange/subaccountDeposit',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExchangeBalances',
    full_name='injective.exchange.v1beta1.Query.ExchangeBalances',
    index=3,
    containing_service=None,
    input_type=_QUERYEXCHANGEBALANCESREQUEST,
    output_type=_QUERYEXCHANGEBALANCESRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/exchange/exchangeBalances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpotMarkets',
    full_name='injective.exchange.v1beta1.Query.SpotMarkets',
    index=4,
    containing_service=None,
    input_type=_QUERYSPOTMARKETSREQUEST,
    output_type=_QUERYSPOTMARKETSRESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/spot/markets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpotMarket',
    full_name='injective.exchange.v1beta1.Query.SpotMarket',
    index=5,
    containing_service=None,
    input_type=_QUERYSPOTMARKETREQUEST,
    output_type=_QUERYSPOTMARKETRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/spot/markets/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpotOrderbook',
    full_name='injective.exchange.v1beta1.Query.SpotOrderbook',
    index=6,
    containing_service=None,
    input_type=_QUERYSPOTORDERBOOKREQUEST,
    output_type=_QUERYSPOTORDERBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\0028\0226/injective/exchange/v1beta1/spot/orderbook/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TraderSpotOrders',
    full_name='injective.exchange.v1beta1.Query.TraderSpotOrders',
    index=7,
    containing_service=None,
    input_type=_QUERYTRADERSPOTORDERSREQUEST,
    output_type=_QUERYTRADERSPOTORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002E\022C/injective/exchange/v1beta1/spot/orders/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpotOrdersByHashes',
    full_name='injective.exchange.v1beta1.Query.SpotOrdersByHashes',
    index=8,
    containing_service=None,
    input_type=_QUERYSPOTORDERSBYHASHESREQUEST,
    output_type=_QUERYSPOTORDERSBYHASHESRESPONSE,
    serialized_options=b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/orders_by_hashes/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountOrders',
    full_name='injective.exchange.v1beta1.Query.SubaccountOrders',
    index=9,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTORDERSREQUEST,
    output_type=_QUERYSUBACCOUNTORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/orders/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TraderSpotTransientOrders',
    full_name='injective.exchange.v1beta1.Query.TraderSpotTransientOrders',
    index=10,
    containing_service=None,
    input_type=_QUERYTRADERSPOTORDERSREQUEST,
    output_type=_QUERYTRADERSPOTORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002O\022M/injective/exchange/v1beta1/spot/transient_orders/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SpotMidPriceAndTOB',
    full_name='injective.exchange.v1beta1.Query.SpotMidPriceAndTOB',
    index=11,
    containing_service=None,
    input_type=_QUERYSPOTMIDPRICEANDTOBREQUEST,
    output_type=_QUERYSPOTMIDPRICEANDTOBRESPONSE,
    serialized_options=b'\202\323\344\223\002@\022>/injective/exchange/v1beta1/spot/mid_price_and_tob/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeMidPriceAndTOB',
    full_name='injective.exchange.v1beta1.Query.DerivativeMidPriceAndTOB',
    index=12,
    containing_service=None,
    input_type=_QUERYDERIVATIVEMIDPRICEANDTOBREQUEST,
    output_type=_QUERYDERIVATIVEMIDPRICEANDTOBRESPONSE,
    serialized_options=b'\202\323\344\223\002F\022D/injective/exchange/v1beta1/derivative/mid_price_and_tob/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeOrderbook',
    full_name='injective.exchange.v1beta1.Query.DerivativeOrderbook',
    index=13,
    containing_service=None,
    input_type=_QUERYDERIVATIVEORDERBOOKREQUEST,
    output_type=_QUERYDERIVATIVEORDERBOOKRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</injective/exchange/v1beta1/derivative/orderbook/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TraderDerivativeOrders',
    full_name='injective.exchange.v1beta1.Query.TraderDerivativeOrders',
    index=14,
    containing_service=None,
    input_type=_QUERYTRADERDERIVATIVEORDERSREQUEST,
    output_type=_QUERYTRADERDERIVATIVEORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002K\022I/injective/exchange/v1beta1/derivative/orders/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeOrdersByHashes',
    full_name='injective.exchange.v1beta1.Query.DerivativeOrdersByHashes',
    index=15,
    containing_service=None,
    input_type=_QUERYDERIVATIVEORDERSBYHASHESREQUEST,
    output_type=_QUERYDERIVATIVEORDERSBYHASHESRESPONSE,
    serialized_options=b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/orders_by_hashes/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TraderDerivativeTransientOrders',
    full_name='injective.exchange.v1beta1.Query.TraderDerivativeTransientOrders',
    index=16,
    containing_service=None,
    input_type=_QUERYTRADERDERIVATIVEORDERSREQUEST,
    output_type=_QUERYTRADERDERIVATIVEORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002U\022S/injective/exchange/v1beta1/derivative/transient_orders/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeMarkets',
    full_name='injective.exchange.v1beta1.Query.DerivativeMarkets',
    index=17,
    containing_service=None,
    input_type=_QUERYDERIVATIVEMARKETSREQUEST,
    output_type=_QUERYDERIVATIVEMARKETSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./injective/exchange/v1beta1/derivative/markets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeMarket',
    full_name='injective.exchange.v1beta1.Query.DerivativeMarket',
    index=18,
    containing_service=None,
    input_type=_QUERYDERIVATIVEMARKETREQUEST,
    output_type=_QUERYDERIVATIVEMARKETRESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/derivative/markets/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DerivativeMarketAddress',
    full_name='injective.exchange.v1beta1.Query.DerivativeMarketAddress',
    index=19,
    containing_service=None,
    input_type=_QUERYDERIVATIVEMARKETADDRESSREQUEST,
    output_type=_QUERYDERIVATIVEMARKETADDRESSRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/derivative/market_address/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountTradeNonce',
    full_name='injective.exchange.v1beta1.Query.SubaccountTradeNonce',
    index=20,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTTRADENONCEREQUEST,
    output_type=_QUERYSUBACCOUNTTRADENONCERESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/exchange/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExchangeModuleState',
    full_name='injective.exchange.v1beta1.Query.ExchangeModuleState',
    index=21,
    containing_service=None,
    input_type=_QUERYMODULESTATEREQUEST,
    output_type=_QUERYMODULESTATERESPONSE,
    serialized_options=b'\202\323\344\223\002*\022(/injective/exchange/v1beta1/module_state',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Positions',
    full_name='injective.exchange.v1beta1.Query.Positions',
    index=22,
    containing_service=None,
    input_type=_QUERYPOSITIONSREQUEST,
    output_type=_QUERYPOSITIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\'\022%/injective/exchange/v1beta1/positions',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountPositions',
    full_name='injective.exchange.v1beta1.Query.SubaccountPositions',
    index=23,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTPOSITIONSREQUEST,
    output_type=_QUERYSUBACCOUNTPOSITIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0027\0225/injective/exchange/v1beta1/positions/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountPositionInMarket',
    full_name='injective.exchange.v1beta1.Query.SubaccountPositionInMarket',
    index=24,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTPOSITIONINMARKETREQUEST,
    output_type=_QUERYSUBACCOUNTPOSITIONINMARKETRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/positions/{subaccount_id}/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountEffectivePositionInMarket',
    full_name='injective.exchange.v1beta1.Query.SubaccountEffectivePositionInMarket',
    index=25,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETREQUEST,
    output_type=_QUERYSUBACCOUNTEFFECTIVEPOSITIONINMARKETRESPONSE,
    serialized_options=b'\202\323\344\223\002M\022K/injective/exchange/v1beta1/effective_positions/{subaccount_id}/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PerpetualMarketInfo',
    full_name='injective.exchange.v1beta1.Query.PerpetualMarketInfo',
    index=26,
    containing_service=None,
    input_type=_QUERYPERPETUALMARKETINFOREQUEST,
    output_type=_QUERYPERPETUALMARKETINFORESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/perpetual_market_info/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ExpiryFuturesMarketInfo',
    full_name='injective.exchange.v1beta1.Query.ExpiryFuturesMarketInfo',
    index=27,
    containing_service=None,
    input_type=_QUERYEXPIRYFUTURESMARKETINFOREQUEST,
    output_type=_QUERYEXPIRYFUTURESMARKETINFORESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/expiry_market_info/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PerpetualMarketFunding',
    full_name='injective.exchange.v1beta1.Query.PerpetualMarketFunding',
    index=28,
    containing_service=None,
    input_type=_QUERYPERPETUALMARKETFUNDINGREQUEST,
    output_type=_QUERYPERPETUALMARKETFUNDINGRESPONSE,
    serialized_options=b'\202\323\344\223\002B\022@/injective/exchange/v1beta1/perpetual_market_funding/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SubaccountOrderMetadata',
    full_name='injective.exchange.v1beta1.Query.SubaccountOrderMetadata',
    index=29,
    containing_service=None,
    input_type=_QUERYSUBACCOUNTORDERMETADATAREQUEST,
    output_type=_QUERYSUBACCOUNTORDERMETADATARESPONSE,
    serialized_options=b'\202\323\344\223\002<\022:/injective/exchange/v1beta1/order_metadata/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TradeRewardPoints',
    full_name='injective.exchange.v1beta1.Query.TradeRewardPoints',
    index=30,
    containing_service=None,
    input_type=_QUERYTRADEREWARDPOINTSREQUEST,
    output_type=_QUERYTRADEREWARDPOINTSRESPONSE,
    serialized_options=b'\202\323\344\223\0021\022//injective/exchange/v1beta1/trade_reward_points',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='PendingTradeRewardPoints',
    full_name='injective.exchange.v1beta1.Query.PendingTradeRewardPoints',
    index=31,
    containing_service=None,
    input_type=_QUERYTRADEREWARDPOINTSREQUEST,
    output_type=_QUERYTRADEREWARDPOINTSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/pending_trade_reward_points',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TradeRewardCampaign',
    full_name='injective.exchange.v1beta1.Query.TradeRewardCampaign',
    index=32,
    containing_service=None,
    input_type=_QUERYTRADEREWARDCAMPAIGNREQUEST,
    output_type=_QUERYTRADEREWARDCAMPAIGNRESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/trade_reward_campaign',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeeDiscountAccountInfo',
    full_name='injective.exchange.v1beta1.Query.FeeDiscountAccountInfo',
    index=33,
    containing_service=None,
    input_type=_QUERYFEEDISCOUNTACCOUNTINFOREQUEST,
    output_type=_QUERYFEEDISCOUNTACCOUNTINFORESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/injective/exchange/v1beta1/fee_discount_account_info/{account}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeeDiscountSchedule',
    full_name='injective.exchange.v1beta1.Query.FeeDiscountSchedule',
    index=34,
    containing_service=None,
    input_type=_QUERYFEEDISCOUNTSCHEDULEREQUEST,
    output_type=_QUERYFEEDISCOUNTSCHEDULERESPONSE,
    serialized_options=b'\202\323\344\223\0023\0221/injective/exchange/v1beta1/fee_discount_schedule',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BalanceMismatches',
    full_name='injective.exchange.v1beta1.Query.BalanceMismatches',
    index=35,
    containing_service=None,
    input_type=_QUERYBALANCEMISMATCHESREQUEST,
    output_type=_QUERYBALANCEMISMATCHESRESPONSE,
    serialized_options=b'\202\323\344\223\002>\022</injective/exchange/v1beta1/balance_mismatches/{dust_factor}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BalanceWithBalanceHolds',
    full_name='injective.exchange.v1beta1.Query.BalanceWithBalanceHolds',
    index=36,
    containing_service=None,
    input_type=_QUERYBALANCEWITHBALANCEHOLDSREQUEST,
    output_type=_QUERYBALANCEWITHBALANCEHOLDSRESPONSE,
    serialized_options=b'\202\323\344\223\0029\0227/injective/exchange/v1beta1/balances_with_balance_holds',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FeeDiscountTierStatistics',
    full_name='injective.exchange.v1beta1.Query.FeeDiscountTierStatistics',
    index=37,
    containing_service=None,
    input_type=_QUERYFEEDISCOUNTTIERSTATISTICSREQUEST,
    output_type=_QUERYFEEDISCOUNTTIERSTATISTICSRESPONSE,
    serialized_options=b'\202\323\344\223\0025\0223/injective/exchange/v1beta1/fee_discount_tier_stats',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='NinjaVaultInfos',
    full_name='injective.exchange.v1beta1.Query.NinjaVaultInfos',
    index=38,
    containing_service=None,
    input_type=_NINJAVAULTINFOSREQUEST,
    output_type=_NINJAVAULTINFOSRESPONSE,
    serialized_options=b'\202\323\344\223\002/\022-/injective/exchange/v1beta1/ninja_vault_infos',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='QueryMarketIDFromVault',
    full_name='injective.exchange.v1beta1.Query.QueryMarketIDFromVault',
    index=39,
    containing_service=None,
    input_type=_QUERYMARKETIDFROMVAULTREQUEST,
    output_type=_QUERYMARKETIDFROMVAULTRESPONSE,
    serialized_options=b'\202\323\344\223\002C\022A/injective/exchange/v1beta1/vault_market_id/{vault_subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='HistoricalTradeRecords',
    full_name='injective.exchange.v1beta1.Query.HistoricalTradeRecords',
    index=40,
    containing_service=None,
    input_type=_QUERYHISTORICALTRADERECORDSREQUEST,
    output_type=_QUERYHISTORICALTRADERECORDSRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/injective/exchange/v1beta1/historical_trade_records',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='IsOptedOutOfRewards',
    full_name='injective.exchange.v1beta1.Query.IsOptedOutOfRewards',
    index=41,
    containing_service=None,
    input_type=_QUERYISOPTEDOUTOFREWARDSREQUEST,
    output_type=_QUERYISOPTEDOUTOFREWARDSRESPONSE,
    serialized_options=b'\202\323\344\223\002?\022=/injective/exchange/v1beta1/is_opted_out_of_rewards/{account}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='OptedOutOfRewardsAccounts',
    full_name='injective.exchange.v1beta1.Query.OptedOutOfRewardsAccounts',
    index=42,
    containing_service=None,
    input_type=_QUERYOPTEDOUTOFREWARDSACCOUNTSREQUEST,
    output_type=_QUERYOPTEDOUTOFREWARDSACCOUNTSRESPONSE,
    serialized_options=b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/opted_out_of_rewards_accounts',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='MarketVolatility',
    full_name='injective.exchange.v1beta1.Query.MarketVolatility',
    index=43,
    containing_service=None,
    input_type=_QUERYMARKETVOLATILITYREQUEST,
    output_type=_QUERYMARKETVOLATILITYRESPONSE,
    serialized_options=b'\202\323\344\223\002;\0229/injective/exchange/v1beta1/market_volatility/{market_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BinaryOptionsMarkets',
    full_name='injective.exchange.v1beta1.Query.BinaryOptionsMarkets',
    index=44,
    containing_service=None,
    input_type=_QUERYBINARYMARKETSREQUEST,
    output_type=_QUERYBINARYMARKETSRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/injective/exchange/v1beta1/binary_options/markets',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='TraderDerivativeConditionalOrders',
    full_name='injective.exchange.v1beta1.Query.TraderDerivativeConditionalOrders',
    index=45,
    containing_service=None,
    input_type=_QUERYTRADERDERIVATIVECONDITIONALORDERSREQUEST,
    output_type=_QUERYTRADERDERIVATIVECONDITIONALORDERSRESPONSE,
    serialized_options=b'\202\323\344\223\002W\022U/injective/exchange/v1beta1/derivative/orders/conditional/{market_id}/{subaccount_id}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_QUERY)

DESCRIPTOR.services_by_name['Query'] = _QUERY

# @@protoc_insertion_point(module_scope)
